pub struct AgentDeleteOutput {
pub deleted: Vec<String>,
pub message: String,
}Fields
deleted: Vec<String>message: StringTrait Implementations
Sourceimpl Clone for AgentDeleteOutput
impl Clone for AgentDeleteOutput
Sourcefn clone(&self) -> AgentDeleteOutput
fn clone(&self) -> AgentDeleteOutput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AgentDeleteOutput
impl Debug for AgentDeleteOutput
Sourceimpl<'de> Deserialize<'de> for AgentDeleteOutput
impl<'de> Deserialize<'de> for AgentDeleteOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AgentDeleteOutput
impl JsonSchema for AgentDeleteOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AgentDeleteOutput
impl RefUnwindSafe for AgentDeleteOutput
impl Send for AgentDeleteOutput
impl Sync for AgentDeleteOutput
impl Unpin for AgentDeleteOutput
impl UnsafeUnpin for AgentDeleteOutput
impl UnwindSafe for AgentDeleteOutput