pub struct AgentEditOutput {
pub name: String,
pub message: String,
pub changes: Vec<String>,
}Fields
name: Stringmessage: Stringchanges: Vec<String>Trait Implementations
Sourceimpl Clone for AgentEditOutput
impl Clone for AgentEditOutput
Sourcefn clone(&self) -> AgentEditOutput
fn clone(&self) -> AgentEditOutput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AgentEditOutput
impl Debug for AgentEditOutput
Sourceimpl<'de> Deserialize<'de> for AgentEditOutput
impl<'de> Deserialize<'de> for AgentEditOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AgentEditOutput
impl JsonSchema for AgentEditOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AgentEditOutput
impl RefUnwindSafe for AgentEditOutput
impl Send for AgentEditOutput
impl Sync for AgentEditOutput
impl Unpin for AgentEditOutput
impl UnwindSafe for AgentEditOutput