pub struct AgentStatusOutput {
pub agents: Vec<AgentStatusRow>,
}Fields
agents: Vec<AgentStatusRow>Trait Implementations
Sourceimpl Clone for AgentStatusOutput
impl Clone for AgentStatusOutput
Sourcefn clone(&self) -> AgentStatusOutput
fn clone(&self) -> AgentStatusOutput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AgentStatusOutput
impl Debug for AgentStatusOutput
Sourceimpl<'de> Deserialize<'de> for AgentStatusOutput
impl<'de> Deserialize<'de> for AgentStatusOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AgentStatusOutput
impl JsonSchema for AgentStatusOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AgentStatusOutput
impl RefUnwindSafe for AgentStatusOutput
impl Send for AgentStatusOutput
impl Sync for AgentStatusOutput
impl Unpin for AgentStatusOutput
impl UnwindSafe for AgentStatusOutput