pub struct AgentStatusRow {
pub name: String,
pub enabled: bool,
pub is_running: bool,
pub pid: Option<u32>,
pub port: u16,
}Fields
name: Stringenabled: boolis_running: boolpid: Option<u32>port: u16Trait Implementations
Sourceimpl Clone for AgentStatusRow
impl Clone for AgentStatusRow
Sourcefn clone(&self) -> AgentStatusRow
fn clone(&self) -> AgentStatusRow
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AgentStatusRow
impl Debug for AgentStatusRow
Sourceimpl<'de> Deserialize<'de> for AgentStatusRow
impl<'de> Deserialize<'de> for AgentStatusRow
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AgentStatusRow
impl JsonSchema for AgentStatusRow
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AgentStatusRow
impl RefUnwindSafe for AgentStatusRow
impl Send for AgentStatusRow
impl Sync for AgentStatusRow
impl Unpin for AgentStatusRow
impl UnwindSafe for AgentStatusRow