pub struct AgentSummary {
pub name: String,
pub display_name: String,
pub port: u16,
pub enabled: bool,
pub is_primary: bool,
pub is_default: bool,
}Fields
name: Stringdisplay_name: Stringport: u16enabled: boolis_primary: boolis_default: boolTrait Implementations
Sourceimpl Clone for AgentSummary
impl Clone for AgentSummary
Sourcefn clone(&self) -> AgentSummary
fn clone(&self) -> AgentSummary
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AgentSummary
impl Debug for AgentSummary
Sourceimpl<'de> Deserialize<'de> for AgentSummary
impl<'de> Deserialize<'de> for AgentSummary
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AgentSummary
impl JsonSchema for AgentSummary
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AgentSummary
impl RefUnwindSafe for AgentSummary
impl Send for AgentSummary
impl Sync for AgentSummary
impl Unpin for AgentSummary
impl UnwindSafe for AgentSummary