pub struct RegistryAgentInfo {
pub name: String,
pub description: String,
pub url: String,
pub version: String,
pub status: String,
pub streaming: bool,
pub skills_count: usize,
pub skills: Vec<String>,
}Fields
name: Stringdescription: Stringurl: Stringversion: Stringstatus: Stringstreaming: boolskills_count: usizeskills: Vec<String>Trait Implementations
Sourceimpl Clone for RegistryAgentInfo
impl Clone for RegistryAgentInfo
Sourcefn clone(&self) -> RegistryAgentInfo
fn clone(&self) -> RegistryAgentInfo
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RegistryAgentInfo
impl Debug for RegistryAgentInfo
Sourceimpl<'de> Deserialize<'de> for RegistryAgentInfo
impl<'de> Deserialize<'de> for RegistryAgentInfo
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RegistryAgentInfo
impl JsonSchema for RegistryAgentInfo
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RegistryAgentInfo
impl RefUnwindSafe for RegistryAgentInfo
impl Send for RegistryAgentInfo
impl Sync for RegistryAgentInfo
impl Unpin for RegistryAgentInfo
impl UnwindSafe for RegistryAgentInfo