pub struct RegistryOutput {
pub gateway_url: String,
pub agents_count: usize,
pub agents: Vec<RegistryAgentInfo>,
}Fields
gateway_url: Stringagents_count: usizeagents: Vec<RegistryAgentInfo>Trait Implementations
Sourceimpl Clone for RegistryOutput
impl Clone for RegistryOutput
Sourcefn clone(&self) -> RegistryOutput
fn clone(&self) -> RegistryOutput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RegistryOutput
impl Debug for RegistryOutput
Sourceimpl<'de> Deserialize<'de> for RegistryOutput
impl<'de> Deserialize<'de> for RegistryOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RegistryOutput
impl JsonSchema for RegistryOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RegistryOutput
impl RefUnwindSafe for RegistryOutput
impl Send for RegistryOutput
impl Sync for RegistryOutput
impl Unpin for RegistryOutput
impl UnwindSafe for RegistryOutput