pub struct BootstrapOutput {
pub id: UserId,
pub name: String,
pub email: String,
pub created: bool,
pub roles: Vec<String>,
pub message: String,
}Fields
id: UserIdname: Stringemail: Stringcreated: boolroles: Vec<String>message: StringTrait Implementations
Sourceimpl Clone for BootstrapOutput
impl Clone for BootstrapOutput
Sourcefn clone(&self) -> BootstrapOutput
fn clone(&self) -> BootstrapOutput
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BootstrapOutput
impl Debug for BootstrapOutput
Sourceimpl<'de> Deserialize<'de> for BootstrapOutput
impl<'de> Deserialize<'de> for BootstrapOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for BootstrapOutput
impl JsonSchema for BootstrapOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for BootstrapOutput
impl RefUnwindSafe for BootstrapOutput
impl Send for BootstrapOutput
impl Sync for BootstrapOutput
impl Unpin for BootstrapOutput
impl UnsafeUnpin for BootstrapOutput
impl UnwindSafe for BootstrapOutput