pub struct ConfigListOutput {
pub total: usize,
pub valid: usize,
pub invalid: usize,
pub files: Vec<ConfigFileInfo>,
}Fields
total: usizevalid: usizeinvalid: usizefiles: Vec<ConfigFileInfo>Trait Implementations
Sourceimpl Clone for ConfigListOutput
impl Clone for ConfigListOutput
Sourcefn clone(&self) -> ConfigListOutput
fn clone(&self) -> ConfigListOutput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ConfigListOutput
impl Debug for ConfigListOutput
Sourceimpl<'de> Deserialize<'de> for ConfigListOutput
impl<'de> Deserialize<'de> for ConfigListOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ConfigListOutput
impl JsonSchema for ConfigListOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ConfigListOutput
impl RefUnwindSafe for ConfigListOutput
impl Send for ConfigListOutput
impl Sync for ConfigListOutput
impl Unpin for ConfigListOutput
impl UnsafeUnpin for ConfigListOutput
impl UnwindSafe for ConfigListOutput