pub struct ExportOutput {
pub format: String,
pub path: String,
pub message: String,
}Fields
format: Stringpath: Stringmessage: StringTrait Implementations
Sourceimpl Clone for ExportOutput
impl Clone for ExportOutput
Sourcefn clone(&self) -> ExportOutput
fn clone(&self) -> ExportOutput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExportOutput
impl Debug for ExportOutput
Sourceimpl<'de> Deserialize<'de> for ExportOutput
impl<'de> Deserialize<'de> for ExportOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ExportOutput
impl JsonSchema for ExportOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ExportOutput
impl RefUnwindSafe for ExportOutput
impl Send for ExportOutput
impl Sync for ExportOutput
impl Unpin for ExportOutput
impl UnsafeUnpin for ExportOutput
impl UnwindSafe for ExportOutput