pub struct ImportOutput {
pub path: String,
pub changes: Vec<ResetChange>,
pub message: String,
}Fields
path: Stringchanges: Vec<ResetChange>message: StringTrait Implementations
Sourceimpl Clone for ImportOutput
impl Clone for ImportOutput
Sourcefn clone(&self) -> ImportOutput
fn clone(&self) -> ImportOutput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ImportOutput
impl Debug for ImportOutput
Sourceimpl<'de> Deserialize<'de> for ImportOutput
impl<'de> Deserialize<'de> for ImportOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ImportOutput
impl JsonSchema for ImportOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ImportOutput
impl RefUnwindSafe for ImportOutput
impl Send for ImportOutput
impl Sync for ImportOutput
impl Unpin for ImportOutput
impl UnsafeUnpin for ImportOutput
impl UnwindSafe for ImportOutput