pub struct BaseRateRow {
pub endpoint: String,
pub rate_per_second: u64,
}Fields
endpoint: Stringrate_per_second: u64Trait Implementations
Sourceimpl Clone for BaseRateRow
impl Clone for BaseRateRow
Sourcefn clone(&self) -> BaseRateRow
fn clone(&self) -> BaseRateRow
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BaseRateRow
impl Debug for BaseRateRow
Sourceimpl<'de> Deserialize<'de> for BaseRateRow
impl<'de> Deserialize<'de> for BaseRateRow
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for BaseRateRow
impl JsonSchema for BaseRateRow
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for BaseRateRow
impl RefUnwindSafe for BaseRateRow
impl Send for BaseRateRow
impl Sync for BaseRateRow
impl Unpin for BaseRateRow
impl UnsafeUnpin for BaseRateRow
impl UnwindSafe for BaseRateRow