pub struct CompareOutput {
pub endpoints: Vec<EndpointComparison>,
}Fields
endpoints: Vec<EndpointComparison>Trait Implementations
Sourceimpl Clone for CompareOutput
impl Clone for CompareOutput
Sourcefn clone(&self) -> CompareOutput
fn clone(&self) -> CompareOutput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CompareOutput
impl Debug for CompareOutput
Sourceimpl<'de> Deserialize<'de> for CompareOutput
impl<'de> Deserialize<'de> for CompareOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CompareOutput
impl JsonSchema for CompareOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for CompareOutput
impl RefUnwindSafe for CompareOutput
impl Send for CompareOutput
impl Sync for CompareOutput
impl Unpin for CompareOutput
impl UnsafeUnpin for CompareOutput
impl UnwindSafe for CompareOutput