pub struct ConfigFileInfo {
pub path: String,
pub section: String,
pub exists: bool,
pub valid: bool,
pub error: Option<String>,
}Fields
path: Stringsection: Stringexists: boolvalid: boolerror: Option<String>Trait Implementations
Sourceimpl Clone for ConfigFileInfo
impl Clone for ConfigFileInfo
Sourcefn clone(&self) -> ConfigFileInfo
fn clone(&self) -> ConfigFileInfo
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ConfigFileInfo
impl Debug for ConfigFileInfo
Sourceimpl<'de> Deserialize<'de> for ConfigFileInfo
impl<'de> Deserialize<'de> for ConfigFileInfo
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ConfigFileInfo
impl JsonSchema for ConfigFileInfo
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ConfigFileInfo
impl RefUnwindSafe for ConfigFileInfo
impl Send for ConfigFileInfo
impl Sync for ConfigFileInfo
impl Unpin for ConfigFileInfo
impl UnwindSafe for ConfigFileInfo