pub struct ConfigOverviewOutput {
pub profile_name: String,
pub profile_path: String,
pub server: ServerOverview,
pub runtime: RuntimeOverview,
pub security: SecurityOverview,
pub paths: PathsOverview,
pub rate_limits: RateLimitsSummary,
}Fields
profile_name: Stringprofile_path: Stringserver: ServerOverviewruntime: RuntimeOverviewsecurity: SecurityOverviewpaths: PathsOverviewrate_limits: RateLimitsSummaryTrait Implementations
Sourceimpl Clone for ConfigOverviewOutput
impl Clone for ConfigOverviewOutput
Sourcefn clone(&self) -> ConfigOverviewOutput
fn clone(&self) -> ConfigOverviewOutput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ConfigOverviewOutput
impl Debug for ConfigOverviewOutput
Sourceimpl<'de> Deserialize<'de> for ConfigOverviewOutput
impl<'de> Deserialize<'de> for ConfigOverviewOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ConfigOverviewOutput
impl JsonSchema for ConfigOverviewOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ConfigOverviewOutput
impl RefUnwindSafe for ConfigOverviewOutput
impl Send for ConfigOverviewOutput
impl Sync for ConfigOverviewOutput
impl Unpin for ConfigOverviewOutput
impl UnsafeUnpin for ConfigOverviewOutput
impl UnwindSafe for ConfigOverviewOutput