pub struct EndpointComparison {
pub endpoint: String,
pub admin: u64,
pub user: u64,
pub a2a: u64,
pub mcp: u64,
pub service: u64,
pub anon: u64,
}Fields
endpoint: Stringadmin: u64user: u64a2a: u64mcp: u64service: u64anon: u64Trait Implementations
Sourceimpl Clone for EndpointComparison
impl Clone for EndpointComparison
Sourcefn clone(&self) -> EndpointComparison
fn clone(&self) -> EndpointComparison
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EndpointComparison
impl Debug for EndpointComparison
Sourceimpl<'de> Deserialize<'de> for EndpointComparison
impl<'de> Deserialize<'de> for EndpointComparison
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for EndpointComparison
impl JsonSchema for EndpointComparison
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for EndpointComparison
impl RefUnwindSafe for EndpointComparison
impl Send for EndpointComparison
impl Sync for EndpointComparison
impl Unpin for EndpointComparison
impl UnwindSafe for EndpointComparison