pub struct EndpointRateLimit {
pub endpoint: String,
pub per_second: u64,
}Fields
endpoint: Stringper_second: u64Trait Implementations
Sourceimpl Clone for EndpointRateLimit
impl Clone for EndpointRateLimit
Sourcefn clone(&self) -> EndpointRateLimit
fn clone(&self) -> EndpointRateLimit
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EndpointRateLimit
impl Debug for EndpointRateLimit
Sourceimpl<'de> Deserialize<'de> for EndpointRateLimit
impl<'de> Deserialize<'de> for EndpointRateLimit
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for EndpointRateLimit
impl JsonSchema for EndpointRateLimit
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for EndpointRateLimit
impl RefUnwindSafe for EndpointRateLimit
impl Send for EndpointRateLimit
impl Sync for EndpointRateLimit
impl Unpin for EndpointRateLimit
impl UnsafeUnpin for EndpointRateLimit
impl UnwindSafe for EndpointRateLimit