pub struct PathsConfigOutput {
pub system: PathInfo,
pub services: PathInfo,
pub bin: PathInfo,
pub web_path: Option<PathInfo>,
pub storage: Option<PathInfo>,
pub geoip_database: Option<PathInfo>,
}Fields
system: PathInfoservices: PathInfobin: PathInfoweb_path: Option<PathInfo>storage: Option<PathInfo>geoip_database: Option<PathInfo>Trait Implementations
Sourceimpl Clone for PathsConfigOutput
impl Clone for PathsConfigOutput
Sourcefn clone(&self) -> PathsConfigOutput
fn clone(&self) -> PathsConfigOutput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PathsConfigOutput
impl Debug for PathsConfigOutput
Sourceimpl<'de> Deserialize<'de> for PathsConfigOutput
impl<'de> Deserialize<'de> for PathsConfigOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for PathsConfigOutput
impl JsonSchema for PathsConfigOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for PathsConfigOutput
impl RefUnwindSafe for PathsConfigOutput
impl Send for PathsConfigOutput
impl Sync for PathsConfigOutput
impl Unpin for PathsConfigOutput
impl UnsafeUnpin for PathsConfigOutput
impl UnwindSafe for PathsConfigOutput