pub struct PathsOverview {
pub system: String,
pub services: String,
pub bin: String,
pub web_path: Option<String>,
pub storage: Option<String>,
}Fields
system: Stringservices: Stringbin: Stringweb_path: Option<String>storage: Option<String>Trait Implementations
Sourceimpl Clone for PathsOverview
impl Clone for PathsOverview
Sourcefn clone(&self) -> PathsOverview
fn clone(&self) -> PathsOverview
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PathsOverview
impl Debug for PathsOverview
Sourceimpl<'de> Deserialize<'de> for PathsOverview
impl<'de> Deserialize<'de> for PathsOverview
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for PathsOverview
impl JsonSchema for PathsOverview
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for PathsOverview
impl RefUnwindSafe for PathsOverview
impl Send for PathsOverview
impl Sync for PathsOverview
impl Unpin for PathsOverview
impl UnwindSafe for PathsOverview