pub struct PresetApplyOutput {
pub preset: String,
pub changes: Vec<ResetChange>,
pub message: String,
}Fields
preset: Stringchanges: Vec<ResetChange>message: StringTrait Implementations
Sourceimpl Clone for PresetApplyOutput
impl Clone for PresetApplyOutput
Sourcefn clone(&self) -> PresetApplyOutput
fn clone(&self) -> PresetApplyOutput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PresetApplyOutput
impl Debug for PresetApplyOutput
Sourceimpl<'de> Deserialize<'de> for PresetApplyOutput
impl<'de> Deserialize<'de> for PresetApplyOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for PresetApplyOutput
impl JsonSchema for PresetApplyOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for PresetApplyOutput
impl RefUnwindSafe for PresetApplyOutput
impl Send for PresetApplyOutput
impl Sync for PresetApplyOutput
impl Unpin for PresetApplyOutput
impl UnsafeUnpin for PresetApplyOutput
impl UnwindSafe for PresetApplyOutput