pub struct PresetInfo {
pub name: String,
pub description: String,
pub builtin: bool,
}Fields
name: Stringdescription: Stringbuiltin: boolTrait Implementations
Sourceimpl Clone for PresetInfo
impl Clone for PresetInfo
Sourcefn clone(&self) -> PresetInfo
fn clone(&self) -> PresetInfo
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PresetInfo
impl Debug for PresetInfo
Sourceimpl<'de> Deserialize<'de> for PresetInfo
impl<'de> Deserialize<'de> for PresetInfo
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for PresetInfo
impl JsonSchema for PresetInfo
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for PresetInfo
impl RefUnwindSafe for PresetInfo
impl Send for PresetInfo
impl Sync for PresetInfo
impl Unpin for PresetInfo
impl UnsafeUnpin for PresetInfo
impl UnwindSafe for PresetInfo