pub struct PresetShowOutput {
pub name: String,
pub description: String,
pub config: RateLimitsOutput,
}Fields
name: Stringdescription: Stringconfig: RateLimitsOutputTrait Implementations
Sourceimpl Clone for PresetShowOutput
impl Clone for PresetShowOutput
Sourcefn clone(&self) -> PresetShowOutput
fn clone(&self) -> PresetShowOutput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PresetShowOutput
impl Debug for PresetShowOutput
Sourceimpl<'de> Deserialize<'de> for PresetShowOutput
impl<'de> Deserialize<'de> for PresetShowOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for PresetShowOutput
impl JsonSchema for PresetShowOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for PresetShowOutput
impl RefUnwindSafe for PresetShowOutput
impl Send for PresetShowOutput
impl Sync for PresetShowOutput
impl Unpin for PresetShowOutput
impl UnwindSafe for PresetShowOutput