pub struct RateLimitStatusOutput {
pub enabled: bool,
pub message: String,
}Fields
enabled: boolmessage: StringTrait Implementations
Sourceimpl Clone for RateLimitStatusOutput
impl Clone for RateLimitStatusOutput
Sourcefn clone(&self) -> RateLimitStatusOutput
fn clone(&self) -> RateLimitStatusOutput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RateLimitStatusOutput
impl Debug for RateLimitStatusOutput
Sourceimpl<'de> Deserialize<'de> for RateLimitStatusOutput
impl<'de> Deserialize<'de> for RateLimitStatusOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RateLimitStatusOutput
impl JsonSchema for RateLimitStatusOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RateLimitStatusOutput
impl RefUnwindSafe for RateLimitStatusOutput
impl Send for RateLimitStatusOutput
impl Sync for RateLimitStatusOutput
impl Unpin for RateLimitStatusOutput
impl UnsafeUnpin for RateLimitStatusOutput
impl UnwindSafe for RateLimitStatusOutput