pub struct RateLimitsOutput {Show 14 fields
pub disabled: bool,
pub oauth_public_per_second: u64,
pub oauth_auth_per_second: u64,
pub contexts_per_second: u64,
pub tasks_per_second: u64,
pub artifacts_per_second: u64,
pub agent_registry_per_second: u64,
pub agents_per_second: u64,
pub mcp_registry_per_second: u64,
pub mcp_per_second: u64,
pub stream_per_second: u64,
pub content_per_second: u64,
pub burst_multiplier: u64,
pub tier_multipliers: TierMultipliersOutput,
}Fields
disabled: booloauth_public_per_second: u64oauth_auth_per_second: u64contexts_per_second: u64tasks_per_second: u64artifacts_per_second: u64agent_registry_per_second: u64agents_per_second: u64mcp_registry_per_second: u64mcp_per_second: u64stream_per_second: u64content_per_second: u64burst_multiplier: u64tier_multipliers: TierMultipliersOutputTrait Implementations
Sourceimpl Clone for RateLimitsOutput
impl Clone for RateLimitsOutput
Sourcefn clone(&self) -> RateLimitsOutput
fn clone(&self) -> RateLimitsOutput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RateLimitsOutput
impl Debug for RateLimitsOutput
Sourceimpl<'de> Deserialize<'de> for RateLimitsOutput
impl<'de> Deserialize<'de> for RateLimitsOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RateLimitsOutput
impl JsonSchema for RateLimitsOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for RateLimitsOutput
impl Serialize for RateLimitsOutput
impl Copy for RateLimitsOutput