pub struct RateLimitsSummary {
pub enabled: bool,
pub burst_multiplier: u64,
pub tier_count: usize,
}Fields
enabled: boolburst_multiplier: u64tier_count: usizeTrait Implementations
Sourceimpl Clone for RateLimitsSummary
impl Clone for RateLimitsSummary
Sourcefn clone(&self) -> RateLimitsSummary
fn clone(&self) -> RateLimitsSummary
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RateLimitsSummary
impl Debug for RateLimitsSummary
Sourceimpl<'de> Deserialize<'de> for RateLimitsSummary
impl<'de> Deserialize<'de> for RateLimitsSummary
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RateLimitsSummary
impl JsonSchema for RateLimitsSummary
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for RateLimitsSummary
impl Serialize for RateLimitsSummary
impl Copy for RateLimitsSummary