pub struct ResetChange {
pub field: String,
pub old_value: String,
pub new_value: String,
}Fields
field: Stringold_value: Stringnew_value: StringTrait Implementations
Sourceimpl Clone for ResetChange
impl Clone for ResetChange
Sourcefn clone(&self) -> ResetChange
fn clone(&self) -> ResetChange
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ResetChange
impl Debug for ResetChange
Sourceimpl<'de> Deserialize<'de> for ResetChange
impl<'de> Deserialize<'de> for ResetChange
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ResetChange
impl JsonSchema for ResetChange
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ResetChange
impl RefUnwindSafe for ResetChange
impl Send for ResetChange
impl Sync for ResetChange
impl Unpin for ResetChange
impl UnwindSafe for ResetChange