pub struct ResetOutput {
pub reset_type: String,
pub changes: Vec<ResetChange>,
pub message: String,
}Fields
reset_type: Stringchanges: Vec<ResetChange>message: StringTrait Implementations
Sourceimpl Clone for ResetOutput
impl Clone for ResetOutput
Sourcefn clone(&self) -> ResetOutput
fn clone(&self) -> ResetOutput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ResetOutput
impl Debug for ResetOutput
Sourceimpl<'de> Deserialize<'de> for ResetOutput
impl<'de> Deserialize<'de> for ResetOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ResetOutput
impl JsonSchema for ResetOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ResetOutput
impl RefUnwindSafe for ResetOutput
impl Send for ResetOutput
impl Sync for ResetOutput
impl Unpin for ResetOutput
impl UnsafeUnpin for ResetOutput
impl UnwindSafe for ResetOutput