pub struct RuntimeOverview {
pub environment: String,
pub log_level: String,
pub output_format: String,
pub no_color: bool,
}Fields
environment: Stringlog_level: Stringoutput_format: Stringno_color: boolTrait Implementations
Sourceimpl Clone for RuntimeOverview
impl Clone for RuntimeOverview
Sourcefn clone(&self) -> RuntimeOverview
fn clone(&self) -> RuntimeOverview
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RuntimeOverview
impl Debug for RuntimeOverview
Sourceimpl<'de> Deserialize<'de> for RuntimeOverview
impl<'de> Deserialize<'de> for RuntimeOverview
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RuntimeOverview
impl JsonSchema for RuntimeOverview
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RuntimeOverview
impl RefUnwindSafe for RuntimeOverview
impl Send for RuntimeOverview
impl Sync for RuntimeOverview
impl Unpin for RuntimeOverview
impl UnwindSafe for RuntimeOverview