pub struct SecurityConfigOutput {
pub jwt_issuer: String,
pub access_token_expiry_seconds: i64,
pub refresh_token_expiry_seconds: i64,
pub audiences: Vec<String>,
}Fields
jwt_issuer: Stringaccess_token_expiry_seconds: i64refresh_token_expiry_seconds: i64audiences: Vec<String>Trait Implementations
Sourceimpl Clone for SecurityConfigOutput
impl Clone for SecurityConfigOutput
Sourcefn clone(&self) -> SecurityConfigOutput
fn clone(&self) -> SecurityConfigOutput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SecurityConfigOutput
impl Debug for SecurityConfigOutput
Sourceimpl<'de> Deserialize<'de> for SecurityConfigOutput
impl<'de> Deserialize<'de> for SecurityConfigOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SecurityConfigOutput
impl JsonSchema for SecurityConfigOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SecurityConfigOutput
impl RefUnwindSafe for SecurityConfigOutput
impl Send for SecurityConfigOutput
impl Sync for SecurityConfigOutput
impl Unpin for SecurityConfigOutput
impl UnwindSafe for SecurityConfigOutput