pub struct SecurityOverview {
pub jwt_issuer: String,
pub access_token_expiry_seconds: i64,
pub refresh_token_expiry_seconds: i64,
pub audiences_count: usize,
}Fields
jwt_issuer: Stringaccess_token_expiry_seconds: i64refresh_token_expiry_seconds: i64audiences_count: usizeTrait Implementations
Sourceimpl Clone for SecurityOverview
impl Clone for SecurityOverview
Sourcefn clone(&self) -> SecurityOverview
fn clone(&self) -> SecurityOverview
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SecurityOverview
impl Debug for SecurityOverview
Sourceimpl<'de> Deserialize<'de> for SecurityOverview
impl<'de> Deserialize<'de> for SecurityOverview
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SecurityOverview
impl JsonSchema for SecurityOverview
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SecurityOverview
impl RefUnwindSafe for SecurityOverview
impl Send for SecurityOverview
impl Sync for SecurityOverview
impl Unpin for SecurityOverview
impl UnsafeUnpin for SecurityOverview
impl UnwindSafe for SecurityOverview