pub struct ServerConfigOutput {
pub host: String,
pub port: u16,
pub api_server_url: String,
pub api_internal_url: String,
pub api_external_url: String,
pub use_https: bool,
pub cors_allowed_origins: Vec<String>,
}Fields
host: Stringport: u16api_server_url: Stringapi_internal_url: Stringapi_external_url: Stringuse_https: boolcors_allowed_origins: Vec<String>Trait Implementations
Sourceimpl Clone for ServerConfigOutput
impl Clone for ServerConfigOutput
Sourcefn clone(&self) -> ServerConfigOutput
fn clone(&self) -> ServerConfigOutput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ServerConfigOutput
impl Debug for ServerConfigOutput
Sourceimpl<'de> Deserialize<'de> for ServerConfigOutput
impl<'de> Deserialize<'de> for ServerConfigOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ServerConfigOutput
impl JsonSchema for ServerConfigOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ServerConfigOutput
impl RefUnwindSafe for ServerConfigOutput
impl Send for ServerConfigOutput
impl Sync for ServerConfigOutput
impl Unpin for ServerConfigOutput
impl UnsafeUnpin for ServerConfigOutput
impl UnwindSafe for ServerConfigOutput