pub struct ServicesSetOutput {
pub field: String,
pub old_value: String,
pub new_value: String,
pub message: String,
}Fields
field: Stringold_value: Stringnew_value: Stringmessage: StringTrait Implementations
Sourceimpl Clone for ServicesSetOutput
impl Clone for ServicesSetOutput
Sourcefn clone(&self) -> ServicesSetOutput
fn clone(&self) -> ServicesSetOutput
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ServicesSetOutput
impl Debug for ServicesSetOutput
Sourceimpl<'de> Deserialize<'de> for ServicesSetOutput
impl<'de> Deserialize<'de> for ServicesSetOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ServicesSetOutput
impl JsonSchema for ServicesSetOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ServicesSetOutput
impl RefUnwindSafe for ServicesSetOutput
impl Send for ServicesSetOutput
impl Sync for ServicesSetOutput
impl Unpin for ServicesSetOutput
impl UnsafeUnpin for ServicesSetOutput
impl UnwindSafe for ServicesSetOutput