pub struct TierEffectiveLimitsOutput {
pub tier: String,
pub multiplier: f64,
pub effective_limits: EffectiveLimitsOutput,
}Fields
tier: Stringmultiplier: f64effective_limits: EffectiveLimitsOutputTrait Implementations
Sourceimpl Clone for TierEffectiveLimitsOutput
impl Clone for TierEffectiveLimitsOutput
Sourcefn clone(&self) -> TierEffectiveLimitsOutput
fn clone(&self) -> TierEffectiveLimitsOutput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TierEffectiveLimitsOutput
impl Debug for TierEffectiveLimitsOutput
Sourceimpl<'de> Deserialize<'de> for TierEffectiveLimitsOutput
impl<'de> Deserialize<'de> for TierEffectiveLimitsOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for TierEffectiveLimitsOutput
impl JsonSchema for TierEffectiveLimitsOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for TierEffectiveLimitsOutput
impl RefUnwindSafe for TierEffectiveLimitsOutput
impl Send for TierEffectiveLimitsOutput
impl Sync for TierEffectiveLimitsOutput
impl Unpin for TierEffectiveLimitsOutput
impl UnwindSafe for TierEffectiveLimitsOutput