pub struct ValidateOutput {
pub valid: bool,
pub errors: Vec<String>,
pub warnings: Vec<String>,
}Fields
valid: boolerrors: Vec<String>warnings: Vec<String>Trait Implementations
Sourceimpl Clone for ValidateOutput
impl Clone for ValidateOutput
Sourcefn clone(&self) -> ValidateOutput
fn clone(&self) -> ValidateOutput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ValidateOutput
impl Debug for ValidateOutput
Sourceimpl<'de> Deserialize<'de> for ValidateOutput
impl<'de> Deserialize<'de> for ValidateOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ValidateOutput
impl JsonSchema for ValidateOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ValidateOutput
impl RefUnwindSafe for ValidateOutput
impl Send for ValidateOutput
impl Sync for ValidateOutput
impl Unpin for ValidateOutput
impl UnsafeUnpin for ValidateOutput
impl UnwindSafe for ValidateOutput