Module session

Module session 

Session management commands.

Copyright (c) systemprompt.io — Business Source License 1.1. See https://systemprompt.io for licensing details.

Modules

login
admin session login command minting a local session and token.
login_helpers
Login helpers resolving identity from cloud credentials.
show
admin session show command listing sessions and routing state.
types
Serializable output types for the admin session command tree.

Enums

SessionCommands

Functions

execute