pub struct SessionInfo {
pub key: String,
pub profile_name: String,
pub user_email: String,
pub session_id: String,
pub context_id: String,
pub is_active: bool,
pub is_expired: bool,
pub expires_in: Option<String>,
pub stale_warning: Option<String>,
}Fields
key: Stringprofile_name: Stringuser_email: Stringsession_id: Stringcontext_id: Stringis_active: boolis_expired: boolexpires_in: Option<String>stale_warning: Option<String>Trait Implementations
Sourceimpl Clone for SessionInfo
impl Clone for SessionInfo
Sourcefn clone(&self) -> SessionInfo
fn clone(&self) -> SessionInfo
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SessionInfo
impl Debug for SessionInfo
Sourceimpl<'de> Deserialize<'de> for SessionInfo
impl<'de> Deserialize<'de> for SessionInfo
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SessionInfo
impl JsonSchema for SessionInfo
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SessionInfo
impl RefUnwindSafe for SessionInfo
impl Send for SessionInfo
impl Sync for SessionInfo
impl Unpin for SessionInfo
impl UnsafeUnpin for SessionInfo
impl UnwindSafe for SessionInfo