pub struct SessionShowOutput {
pub sessions: Vec<SessionInfo>,
pub routing: Option<RoutingInfo>,
}Fields
sessions: Vec<SessionInfo>routing: Option<RoutingInfo>Trait Implementations
Sourceimpl Clone for SessionShowOutput
impl Clone for SessionShowOutput
Sourcefn clone(&self) -> SessionShowOutput
fn clone(&self) -> SessionShowOutput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SessionShowOutput
impl Debug for SessionShowOutput
Sourceimpl<'de> Deserialize<'de> for SessionShowOutput
impl<'de> Deserialize<'de> for SessionShowOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SessionShowOutput
impl JsonSchema for SessionShowOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SessionShowOutput
impl RefUnwindSafe for SessionShowOutput
impl Send for SessionShowOutput
impl Sync for SessionShowOutput
impl Unpin for SessionShowOutput
impl UnwindSafe for SessionShowOutput