pub struct BanAddOutput {
pub ip_address: String,
pub reason: String,
pub expires_at: Option<DateTime<Utc>>,
pub is_permanent: bool,
pub message: String,
}Fields
ip_address: Stringreason: Stringexpires_at: Option<DateTime<Utc>>is_permanent: boolmessage: StringTrait Implementations
Sourceimpl Clone for BanAddOutput
impl Clone for BanAddOutput
Sourcefn clone(&self) -> BanAddOutput
fn clone(&self) -> BanAddOutput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BanAddOutput
impl Debug for BanAddOutput
Sourceimpl<'de> Deserialize<'de> for BanAddOutput
impl<'de> Deserialize<'de> for BanAddOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for BanAddOutput
impl JsonSchema for BanAddOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for BanAddOutput
impl RefUnwindSafe for BanAddOutput
impl Send for BanAddOutput
impl Sync for BanAddOutput
impl Unpin for BanAddOutput
impl UnsafeUnpin for BanAddOutput
impl UnwindSafe for BanAddOutput