pub struct BanListOutput {
pub bans: Vec<BanSummary>,
pub total: usize,
}Fields
bans: Vec<BanSummary>total: usizeTrait Implementations
Sourceimpl Clone for BanListOutput
impl Clone for BanListOutput
Sourcefn clone(&self) -> BanListOutput
fn clone(&self) -> BanListOutput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BanListOutput
impl Debug for BanListOutput
Sourceimpl<'de> Deserialize<'de> for BanListOutput
impl<'de> Deserialize<'de> for BanListOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for BanListOutput
impl JsonSchema for BanListOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for BanListOutput
impl RefUnwindSafe for BanListOutput
impl Send for BanListOutput
impl Sync for BanListOutput
impl Unpin for BanListOutput
impl UnsafeUnpin for BanListOutput
impl UnwindSafe for BanListOutput