pub struct BanSummary {
pub ip_address: String,
pub reason: String,
pub banned_at: DateTime<Utc>,
pub expires_at: Option<DateTime<Utc>>,
pub is_permanent: bool,
pub ban_count: i32,
pub ban_source: Option<String>,
}Fields
ip_address: Stringreason: Stringbanned_at: DateTime<Utc>expires_at: Option<DateTime<Utc>>is_permanent: boolban_count: i32ban_source: Option<String>Trait Implementations
Sourceimpl Clone for BanSummary
impl Clone for BanSummary
Sourcefn clone(&self) -> BanSummary
fn clone(&self) -> BanSummary
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BanSummary
impl Debug for BanSummary
Sourceimpl<'de> Deserialize<'de> for BanSummary
impl<'de> Deserialize<'de> for BanSummary
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for BanSummary
impl JsonSchema for BanSummary
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for BanSummary
impl RefUnwindSafe for BanSummary
impl Send for BanSummary
impl Sync for BanSummary
impl Unpin for BanSummary
impl UnsafeUnpin for BanSummary
impl UnwindSafe for BanSummary