pub struct BulkDeleteOutput {
pub deleted: u64,
pub message: String,
}Fields
deleted: u64message: StringTrait Implementations
Sourceimpl Clone for BulkDeleteOutput
impl Clone for BulkDeleteOutput
Sourcefn clone(&self) -> BulkDeleteOutput
fn clone(&self) -> BulkDeleteOutput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BulkDeleteOutput
impl Debug for BulkDeleteOutput
Sourceimpl<'de> Deserialize<'de> for BulkDeleteOutput
impl<'de> Deserialize<'de> for BulkDeleteOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for BulkDeleteOutput
impl JsonSchema for BulkDeleteOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for BulkDeleteOutput
impl RefUnwindSafe for BulkDeleteOutput
impl Send for BulkDeleteOutput
impl Sync for BulkDeleteOutput
impl Unpin for BulkDeleteOutput
impl UnsafeUnpin for BulkDeleteOutput
impl UnwindSafe for BulkDeleteOutput