pub struct BulkUpdateOutput {
pub updated: u64,
pub message: String,
}Fields
updated: u64message: StringTrait Implementations
Sourceimpl Clone for BulkUpdateOutput
impl Clone for BulkUpdateOutput
Sourcefn clone(&self) -> BulkUpdateOutput
fn clone(&self) -> BulkUpdateOutput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BulkUpdateOutput
impl Debug for BulkUpdateOutput
Sourceimpl<'de> Deserialize<'de> for BulkUpdateOutput
impl<'de> Deserialize<'de> for BulkUpdateOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for BulkUpdateOutput
impl JsonSchema for BulkUpdateOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for BulkUpdateOutput
impl RefUnwindSafe for BulkUpdateOutput
impl Send for BulkUpdateOutput
impl Sync for BulkUpdateOutput
impl Unpin for BulkUpdateOutput
impl UnwindSafe for BulkUpdateOutput