pub struct RoleAssignOutput {
pub id: UserId,
pub name: String,
pub roles: Vec<String>,
pub message: String,
}Fields
id: UserIdname: Stringroles: Vec<String>message: StringTrait Implementations
Sourceimpl Clone for RoleAssignOutput
impl Clone for RoleAssignOutput
Sourcefn clone(&self) -> RoleAssignOutput
fn clone(&self) -> RoleAssignOutput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RoleAssignOutput
impl Debug for RoleAssignOutput
Sourceimpl<'de> Deserialize<'de> for RoleAssignOutput
impl<'de> Deserialize<'de> for RoleAssignOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RoleAssignOutput
impl JsonSchema for RoleAssignOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RoleAssignOutput
impl RefUnwindSafe for RoleAssignOutput
impl Send for RoleAssignOutput
impl Sync for RoleAssignOutput
impl Unpin for RoleAssignOutput
impl UnwindSafe for RoleAssignOutput