pub struct SessionSummary {
pub session_id: SessionId,
pub ip_address: Option<String>,
pub user_agent: Option<String>,
pub device_type: Option<String>,
pub started_at: Option<DateTime<Utc>>,
pub last_activity_at: Option<DateTime<Utc>>,
pub is_active: bool,
}Fields
session_id: SessionIdip_address: Option<String>user_agent: Option<String>device_type: Option<String>started_at: Option<DateTime<Utc>>last_activity_at: Option<DateTime<Utc>>is_active: boolTrait Implementations
Sourceimpl Clone for SessionSummary
impl Clone for SessionSummary
Sourcefn clone(&self) -> SessionSummary
fn clone(&self) -> SessionSummary
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SessionSummary
impl Debug for SessionSummary
Sourceimpl<'de> Deserialize<'de> for SessionSummary
impl<'de> Deserialize<'de> for SessionSummary
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SessionSummary
impl JsonSchema for SessionSummary
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SessionSummary
impl RefUnwindSafe for SessionSummary
impl Send for SessionSummary
impl Sync for SessionSummary
impl Unpin for SessionSummary
impl UnsafeUnpin for SessionSummary
impl UnwindSafe for SessionSummary