pub struct UserActivityOutput {
pub user_id: UserId,
pub last_active: Option<DateTime<Utc>>,
pub session_count: i64,
pub task_count: i64,
pub message_count: i64,
}Fields
user_id: UserIdlast_active: Option<DateTime<Utc>>session_count: i64task_count: i64message_count: i64Trait Implementations
Sourceimpl Clone for UserActivityOutput
impl Clone for UserActivityOutput
Sourcefn clone(&self) -> UserActivityOutput
fn clone(&self) -> UserActivityOutput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UserActivityOutput
impl Debug for UserActivityOutput
Sourceimpl<'de> Deserialize<'de> for UserActivityOutput
impl<'de> Deserialize<'de> for UserActivityOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for UserActivityOutput
impl JsonSchema for UserActivityOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for UserActivityOutput
impl RefUnwindSafe for UserActivityOutput
impl Send for UserActivityOutput
impl Sync for UserActivityOutput
impl Unpin for UserActivityOutput
impl UnwindSafe for UserActivityOutput