pub struct UserCountBreakdownOutput {
pub total: i64,
pub by_status: HashMap<String, i64>,
pub by_role: HashMap<String, i64>,
}Fields
total: i64by_status: HashMap<String, i64>by_role: HashMap<String, i64>Trait Implementations
Sourceimpl Clone for UserCountBreakdownOutput
impl Clone for UserCountBreakdownOutput
Sourcefn clone(&self) -> UserCountBreakdownOutput
fn clone(&self) -> UserCountBreakdownOutput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UserCountBreakdownOutput
impl Debug for UserCountBreakdownOutput
Sourceimpl<'de> Deserialize<'de> for UserCountBreakdownOutput
impl<'de> Deserialize<'de> for UserCountBreakdownOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for UserCountBreakdownOutput
impl JsonSchema for UserCountBreakdownOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for UserCountBreakdownOutput
impl RefUnwindSafe for UserCountBreakdownOutput
impl Send for UserCountBreakdownOutput
impl Sync for UserCountBreakdownOutput
impl Unpin for UserCountBreakdownOutput
impl UnwindSafe for UserCountBreakdownOutput