pub struct UserCountOutput {
pub count: i64,
}Fields
count: i64Trait Implementations
Sourceimpl Clone for UserCountOutput
impl Clone for UserCountOutput
Sourcefn clone(&self) -> UserCountOutput
fn clone(&self) -> UserCountOutput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UserCountOutput
impl Debug for UserCountOutput
Sourceimpl<'de> Deserialize<'de> for UserCountOutput
impl<'de> Deserialize<'de> for UserCountOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for UserCountOutput
impl JsonSchema for UserCountOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for UserCountOutput
impl Serialize for UserCountOutput
impl Copy for UserCountOutput