pub struct UserCreatedOutput {
pub id: UserId,
pub name: String,
pub email: String,
pub message: String,
}Fields
id: UserIdname: Stringemail: Stringmessage: StringTrait Implementations
Sourceimpl Clone for UserCreatedOutput
impl Clone for UserCreatedOutput
Sourcefn clone(&self) -> UserCreatedOutput
fn clone(&self) -> UserCreatedOutput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UserCreatedOutput
impl Debug for UserCreatedOutput
Sourceimpl<'de> Deserialize<'de> for UserCreatedOutput
impl<'de> Deserialize<'de> for UserCreatedOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for UserCreatedOutput
impl JsonSchema for UserCreatedOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for UserCreatedOutput
impl RefUnwindSafe for UserCreatedOutput
impl Send for UserCreatedOutput
impl Sync for UserCreatedOutput
impl Unpin for UserCreatedOutput
impl UnsafeUnpin for UserCreatedOutput
impl UnwindSafe for UserCreatedOutput