pub struct UserExportOutput {
pub users: Vec<UserExportItem>,
pub total: usize,
pub exported_at: DateTime<Utc>,
}Fields
users: Vec<UserExportItem>total: usizeexported_at: DateTime<Utc>Trait Implementations
Sourceimpl Clone for UserExportOutput
impl Clone for UserExportOutput
Sourcefn clone(&self) -> UserExportOutput
fn clone(&self) -> UserExportOutput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UserExportOutput
impl Debug for UserExportOutput
Sourceimpl<'de> Deserialize<'de> for UserExportOutput
impl<'de> Deserialize<'de> for UserExportOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for UserExportOutput
impl JsonSchema for UserExportOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for UserExportOutput
impl RefUnwindSafe for UserExportOutput
impl Send for UserExportOutput
impl Sync for UserExportOutput
impl Unpin for UserExportOutput
impl UnsafeUnpin for UserExportOutput
impl UnwindSafe for UserExportOutput