pub struct UserStatsOutput {
pub total: i64,
pub created_24h: i64,
pub created_7d: i64,
pub created_30d: i64,
pub active: i64,
pub suspended: i64,
pub admins: i64,
pub anonymous: i64,
pub bots: i64,
pub oldest_user: Option<DateTime<Utc>>,
pub newest_user: Option<DateTime<Utc>>,
}Fields
total: i64created_24h: i64created_7d: i64created_30d: i64active: i64suspended: i64admins: i64anonymous: i64bots: i64oldest_user: Option<DateTime<Utc>>newest_user: Option<DateTime<Utc>>Trait Implementations
Sourceimpl Clone for UserStatsOutput
impl Clone for UserStatsOutput
Sourcefn clone(&self) -> UserStatsOutput
fn clone(&self) -> UserStatsOutput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UserStatsOutput
impl Debug for UserStatsOutput
Sourceimpl<'de> Deserialize<'de> for UserStatsOutput
impl<'de> Deserialize<'de> for UserStatsOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for UserStatsOutput
impl JsonSchema for UserStatsOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for UserStatsOutput
impl Serialize for UserStatsOutput
impl Copy for UserStatsOutput