pub struct WebauthnSetupTokenOutput {
pub user_email: String,
pub token: String,
pub registration_url: String,
pub expires_minutes: u32,
}Fields
user_email: Stringtoken: Stringregistration_url: Stringexpires_minutes: u32Trait Implementations
Sourceimpl Clone for WebauthnSetupTokenOutput
impl Clone for WebauthnSetupTokenOutput
Sourcefn clone(&self) -> WebauthnSetupTokenOutput
fn clone(&self) -> WebauthnSetupTokenOutput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for WebauthnSetupTokenOutput
impl Debug for WebauthnSetupTokenOutput
Sourceimpl<'de> Deserialize<'de> for WebauthnSetupTokenOutput
impl<'de> Deserialize<'de> for WebauthnSetupTokenOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for WebauthnSetupTokenOutput
impl JsonSchema for WebauthnSetupTokenOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for WebauthnSetupTokenOutput
impl RefUnwindSafe for WebauthnSetupTokenOutput
impl Send for WebauthnSetupTokenOutput
impl Sync for WebauthnSetupTokenOutput
impl Unpin for WebauthnSetupTokenOutput
impl UnwindSafe for WebauthnSetupTokenOutput