pub struct AgentListRow {
pub agent_name: String,
pub task_count: i64,
pub success_rate: f64,
pub avg_execution_time_ms: i64,
pub total_cost_cents: i64,
pub last_active: String,
}Fields
agent_name: Stringtask_count: i64success_rate: f64avg_execution_time_ms: i64total_cost_cents: i64last_active: StringTrait Implementations
Sourceimpl Clone for AgentListRow
impl Clone for AgentListRow
Sourcefn clone(&self) -> AgentListRow
fn clone(&self) -> AgentListRow
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AgentListRow
impl Debug for AgentListRow
Sourceimpl<'de> Deserialize<'de> for AgentListRow
impl<'de> Deserialize<'de> for AgentListRow
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AgentListRow
impl JsonSchema for AgentListRow
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AgentListRow
impl RefUnwindSafe for AgentListRow
impl Send for AgentListRow
impl Sync for AgentListRow
impl Unpin for AgentListRow
impl UnwindSafe for AgentListRow