pub struct AgentStatsOutput {
pub period: String,
pub total_agents: i64,
pub total_tasks: i64,
pub completed_tasks: i64,
pub failed_tasks: i64,
pub success_rate: f64,
pub avg_execution_time_ms: i64,
pub total_ai_requests: i64,
pub total_cost_microdollars: i64,
}Fields
period: Stringtotal_agents: i64total_tasks: i64completed_tasks: i64failed_tasks: i64success_rate: f64avg_execution_time_ms: i64total_ai_requests: i64total_cost_microdollars: i64Trait Implementations
Sourceimpl Clone for AgentStatsOutput
impl Clone for AgentStatsOutput
Sourcefn clone(&self) -> AgentStatsOutput
fn clone(&self) -> AgentStatsOutput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AgentStatsOutput
impl Debug for AgentStatsOutput
Sourceimpl<'de> Deserialize<'de> for AgentStatsOutput
impl<'de> Deserialize<'de> for AgentStatsOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AgentStatsOutput
impl JsonSchema for AgentStatsOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AgentStatsOutput
impl RefUnwindSafe for AgentStatsOutput
impl Send for AgentStatsOutput
impl Sync for AgentStatsOutput
impl Unpin for AgentStatsOutput
impl UnwindSafe for AgentStatsOutput