pub struct AgentTrendPoint {
pub timestamp: String,
pub task_count: i64,
pub success_rate: f64,
pub avg_execution_time_ms: i64,
}Fields
timestamp: Stringtask_count: i64success_rate: f64avg_execution_time_ms: i64Trait Implementations
Sourceimpl Clone for AgentTrendPoint
impl Clone for AgentTrendPoint
Sourcefn clone(&self) -> AgentTrendPoint
fn clone(&self) -> AgentTrendPoint
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AgentTrendPoint
impl Debug for AgentTrendPoint
Sourceimpl<'de> Deserialize<'de> for AgentTrendPoint
impl<'de> Deserialize<'de> for AgentTrendPoint
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AgentTrendPoint
impl JsonSchema for AgentTrendPoint
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AgentTrendPoint
impl RefUnwindSafe for AgentTrendPoint
impl Send for AgentTrendPoint
impl Sync for AgentTrendPoint
impl Unpin for AgentTrendPoint
impl UnwindSafe for AgentTrendPoint