pub struct HourlyDistributionItem {
pub hour: i32,
pub count: i64,
}Fields
hour: i32count: i64Trait Implementations
Sourceimpl Clone for HourlyDistributionItem
impl Clone for HourlyDistributionItem
Sourcefn clone(&self) -> HourlyDistributionItem
fn clone(&self) -> HourlyDistributionItem
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for HourlyDistributionItem
impl Debug for HourlyDistributionItem
Sourceimpl<'de> Deserialize<'de> for HourlyDistributionItem
impl<'de> Deserialize<'de> for HourlyDistributionItem
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for HourlyDistributionItem
impl JsonSchema for HourlyDistributionItem
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for HourlyDistributionItem
impl Serialize for HourlyDistributionItem
impl Copy for HourlyDistributionItem