pub struct ContentStatsOutput {
pub period: String,
pub total_views: i64,
pub unique_visitors: i64,
pub avg_time_on_page_seconds: i64,
pub avg_scroll_depth: f64,
pub total_clicks: i64,
}Fields
period: Stringtotal_views: i64unique_visitors: i64avg_time_on_page_seconds: i64avg_scroll_depth: f64total_clicks: i64Trait Implementations
Sourceimpl Clone for ContentStatsOutput
impl Clone for ContentStatsOutput
Sourcefn clone(&self) -> ContentStatsOutput
fn clone(&self) -> ContentStatsOutput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ContentStatsOutput
impl Debug for ContentStatsOutput
Sourceimpl<'de> Deserialize<'de> for ContentStatsOutput
impl<'de> Deserialize<'de> for ContentStatsOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ContentStatsOutput
impl JsonSchema for ContentStatsOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ContentStatsOutput
impl RefUnwindSafe for ContentStatsOutput
impl Send for ContentStatsOutput
impl Sync for ContentStatsOutput
impl Unpin for ContentStatsOutput
impl UnsafeUnpin for ContentStatsOutput
impl UnwindSafe for ContentStatsOutput