pub struct ContentTrendPoint {
pub timestamp: String,
pub views: i64,
pub unique_visitors: i64,
}Fields
timestamp: Stringviews: i64unique_visitors: i64Trait Implementations
Sourceimpl Clone for ContentTrendPoint
impl Clone for ContentTrendPoint
Sourcefn clone(&self) -> ContentTrendPoint
fn clone(&self) -> ContentTrendPoint
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ContentTrendPoint
impl Debug for ContentTrendPoint
Sourceimpl<'de> Deserialize<'de> for ContentTrendPoint
impl<'de> Deserialize<'de> for ContentTrendPoint
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ContentTrendPoint
impl JsonSchema for ContentTrendPoint
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ContentTrendPoint
impl RefUnwindSafe for ContentTrendPoint
impl Send for ContentTrendPoint
impl Sync for ContentTrendPoint
impl Unpin for ContentTrendPoint
impl UnwindSafe for ContentTrendPoint