pub struct TopContentOutput {
pub period: String,
pub content: Vec<TopContentRow>,
}Fields
period: Stringcontent: Vec<TopContentRow>Trait Implementations
Sourceimpl Clone for TopContentOutput
impl Clone for TopContentOutput
Sourcefn clone(&self) -> TopContentOutput
fn clone(&self) -> TopContentOutput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TopContentOutput
impl Debug for TopContentOutput
Sourceimpl<'de> Deserialize<'de> for TopContentOutput
impl<'de> Deserialize<'de> for TopContentOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for TopContentOutput
impl JsonSchema for TopContentOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for TopContentOutput
impl RefUnwindSafe for TopContentOutput
impl Send for TopContentOutput
impl Sync for TopContentOutput
impl Unpin for TopContentOutput
impl UnsafeUnpin for TopContentOutput
impl UnwindSafe for TopContentOutput