pub struct TopContentRow {
pub content_id: String,
pub views: i64,
pub unique_visitors: i64,
pub avg_time_seconds: i64,
pub trend: String,
}Fields
content_id: Stringviews: i64unique_visitors: i64avg_time_seconds: i64trend: StringTrait Implementations
Sourceimpl Clone for TopContentRow
impl Clone for TopContentRow
Sourcefn clone(&self) -> TopContentRow
fn clone(&self) -> TopContentRow
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TopContentRow
impl Debug for TopContentRow
Sourceimpl<'de> Deserialize<'de> for TopContentRow
impl<'de> Deserialize<'de> for TopContentRow
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for TopContentRow
impl JsonSchema for TopContentRow
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for TopContentRow
impl RefUnwindSafe for TopContentRow
impl Send for TopContentRow
impl Sync for TopContentRow
impl Unpin for TopContentRow
impl UnwindSafe for TopContentRow