pub struct ConversationListOutput {
pub conversations: Vec<ConversationListRow>,
pub total: i64,
}Fields
conversations: Vec<ConversationListRow>total: i64Trait Implementations
Sourceimpl Clone for ConversationListOutput
impl Clone for ConversationListOutput
Sourcefn clone(&self) -> ConversationListOutput
fn clone(&self) -> ConversationListOutput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ConversationListOutput
impl Debug for ConversationListOutput
Sourceimpl<'de> Deserialize<'de> for ConversationListOutput
impl<'de> Deserialize<'de> for ConversationListOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ConversationListOutput
impl JsonSchema for ConversationListOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ConversationListOutput
impl RefUnwindSafe for ConversationListOutput
impl Send for ConversationListOutput
impl Sync for ConversationListOutput
impl Unpin for ConversationListOutput
impl UnwindSafe for ConversationListOutput