pub struct ConversationStatsOutput {
pub period: String,
pub total_contexts: i64,
pub total_tasks: i64,
pub total_messages: i64,
pub avg_messages_per_task: f64,
pub avg_task_duration_ms: i64,
}Fields
period: Stringtotal_contexts: i64total_tasks: i64total_messages: i64avg_messages_per_task: f64avg_task_duration_ms: i64Trait Implementations
Sourceimpl Clone for ConversationStatsOutput
impl Clone for ConversationStatsOutput
Sourcefn clone(&self) -> ConversationStatsOutput
fn clone(&self) -> ConversationStatsOutput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ConversationStatsOutput
impl Debug for ConversationStatsOutput
Sourceimpl<'de> Deserialize<'de> for ConversationStatsOutput
impl<'de> Deserialize<'de> for ConversationStatsOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ConversationStatsOutput
impl JsonSchema for ConversationStatsOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ConversationStatsOutput
impl RefUnwindSafe for ConversationStatsOutput
impl Send for ConversationStatsOutput
impl Sync for ConversationStatsOutput
impl Unpin for ConversationStatsOutput
impl UnsafeUnpin for ConversationStatsOutput
impl UnwindSafe for ConversationStatsOutput