pub struct ConversationTrendsOutput {
pub period: String,
pub group_by: String,
pub points: Vec<ConversationTrendPoint>,
}Fields
period: Stringgroup_by: Stringpoints: Vec<ConversationTrendPoint>Trait Implementations
Sourceimpl Clone for ConversationTrendsOutput
impl Clone for ConversationTrendsOutput
Sourcefn clone(&self) -> ConversationTrendsOutput
fn clone(&self) -> ConversationTrendsOutput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ConversationTrendsOutput
impl Debug for ConversationTrendsOutput
Sourceimpl<'de> Deserialize<'de> for ConversationTrendsOutput
impl<'de> Deserialize<'de> for ConversationTrendsOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ConversationTrendsOutput
impl JsonSchema for ConversationTrendsOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ConversationTrendsOutput
impl RefUnwindSafe for ConversationTrendsOutput
impl Send for ConversationTrendsOutput
impl Sync for ConversationTrendsOutput
impl Unpin for ConversationTrendsOutput
impl UnwindSafe for ConversationTrendsOutput