pub struct CostBreakdownItem {
pub name: String,
pub cost_microdollars: i64,
pub request_count: i64,
pub tokens: i64,
pub percentage: f64,
}Fields
name: Stringcost_microdollars: i64request_count: i64tokens: i64percentage: f64Trait Implementations
Sourceimpl Clone for CostBreakdownItem
impl Clone for CostBreakdownItem
Sourcefn clone(&self) -> CostBreakdownItem
fn clone(&self) -> CostBreakdownItem
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CostBreakdownItem
impl Debug for CostBreakdownItem
Sourceimpl<'de> Deserialize<'de> for CostBreakdownItem
impl<'de> Deserialize<'de> for CostBreakdownItem
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CostBreakdownItem
impl JsonSchema for CostBreakdownItem
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for CostBreakdownItem
impl RefUnwindSafe for CostBreakdownItem
impl Send for CostBreakdownItem
impl Sync for CostBreakdownItem
impl Unpin for CostBreakdownItem
impl UnsafeUnpin for CostBreakdownItem
impl UnwindSafe for CostBreakdownItem