pub struct CostSummaryOutput {
pub period: String,
pub total_cost_microdollars: i64,
pub total_requests: i64,
pub total_tokens: i64,
pub avg_cost_per_request_microdollars: f64,
pub change_percent: Option<f64>,
}Fields
period: Stringtotal_cost_microdollars: i64total_requests: i64total_tokens: i64avg_cost_per_request_microdollars: f64change_percent: Option<f64>Trait Implementations
Sourceimpl Clone for CostSummaryOutput
impl Clone for CostSummaryOutput
Sourcefn clone(&self) -> CostSummaryOutput
fn clone(&self) -> CostSummaryOutput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CostSummaryOutput
impl Debug for CostSummaryOutput
Sourceimpl<'de> Deserialize<'de> for CostSummaryOutput
impl<'de> Deserialize<'de> for CostSummaryOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CostSummaryOutput
impl JsonSchema for CostSummaryOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for CostSummaryOutput
impl RefUnwindSafe for CostSummaryOutput
impl Send for CostSummaryOutput
impl Sync for CostSummaryOutput
impl Unpin for CostSummaryOutput
impl UnsafeUnpin for CostSummaryOutput
impl UnwindSafe for CostSummaryOutput