pub struct CostTrendsOutput {
pub period: String,
pub group_by: String,
pub points: Vec<CostTrendPoint>,
pub total_cost_cents: i64,
}Fields
period: Stringgroup_by: Stringpoints: Vec<CostTrendPoint>total_cost_cents: i64Trait Implementations
Sourceimpl Clone for CostTrendsOutput
impl Clone for CostTrendsOutput
Sourcefn clone(&self) -> CostTrendsOutput
fn clone(&self) -> CostTrendsOutput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CostTrendsOutput
impl Debug for CostTrendsOutput
Sourceimpl<'de> Deserialize<'de> for CostTrendsOutput
impl<'de> Deserialize<'de> for CostTrendsOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CostTrendsOutput
impl JsonSchema for CostTrendsOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for CostTrendsOutput
impl RefUnwindSafe for CostTrendsOutput
impl Send for CostTrendsOutput
impl Sync for CostTrendsOutput
impl Unpin for CostTrendsOutput
impl UnsafeUnpin for CostTrendsOutput
impl UnwindSafe for CostTrendsOutput