pub struct AgentMetrics {
pub active_count: i64,
pub total_tasks: i64,
pub success_rate: f64,
}Fields
active_count: i64total_tasks: i64success_rate: f64Trait Implementations
Sourceimpl Clone for AgentMetrics
impl Clone for AgentMetrics
Sourcefn clone(&self) -> AgentMetrics
fn clone(&self) -> AgentMetrics
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AgentMetrics
impl Debug for AgentMetrics
Sourceimpl<'de> Deserialize<'de> for AgentMetrics
impl<'de> Deserialize<'de> for AgentMetrics
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AgentMetrics
impl JsonSchema for AgentMetrics
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for AgentMetrics
impl Serialize for AgentMetrics
impl Copy for AgentMetrics