pub struct ConversationMetrics {
pub total: i64,
pub change_percent: Option<f64>,
}Fields
total: i64change_percent: Option<f64>Trait Implementations
Sourceimpl Clone for ConversationMetrics
impl Clone for ConversationMetrics
Sourcefn clone(&self) -> ConversationMetrics
fn clone(&self) -> ConversationMetrics
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ConversationMetrics
impl Debug for ConversationMetrics
Sourceimpl<'de> Deserialize<'de> for ConversationMetrics
impl<'de> Deserialize<'de> for ConversationMetrics
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ConversationMetrics
impl JsonSchema for ConversationMetrics
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for ConversationMetrics
impl Serialize for ConversationMetrics
impl Copy for ConversationMetrics