pub struct OverviewOutput {
pub period: String,
pub conversations: ConversationMetrics,
pub agents: AgentMetrics,
pub requests: RequestMetrics,
pub tools: ToolMetrics,
pub sessions: SessionMetrics,
pub costs: CostMetrics,
}Fields
period: Stringconversations: ConversationMetricsagents: AgentMetricsrequests: RequestMetricstools: ToolMetricssessions: SessionMetricscosts: CostMetricsTrait Implementations
Sourceimpl Clone for OverviewOutput
impl Clone for OverviewOutput
Sourcefn clone(&self) -> OverviewOutput
fn clone(&self) -> OverviewOutput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for OverviewOutput
impl Debug for OverviewOutput
Sourceimpl<'de> Deserialize<'de> for OverviewOutput
impl<'de> Deserialize<'de> for OverviewOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for OverviewOutput
impl JsonSchema for OverviewOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for OverviewOutput
impl RefUnwindSafe for OverviewOutput
impl Send for OverviewOutput
impl Sync for OverviewOutput
impl Unpin for OverviewOutput
impl UnwindSafe for OverviewOutput