pub struct ToolMetrics {
pub total_executions: i64,
pub success_rate: f64,
}Fields
total_executions: i64success_rate: f64Trait Implementations
Sourceimpl Clone for ToolMetrics
impl Clone for ToolMetrics
Sourcefn clone(&self) -> ToolMetrics
fn clone(&self) -> ToolMetrics
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ToolMetrics
impl Debug for ToolMetrics
Sourceimpl<'de> Deserialize<'de> for ToolMetrics
impl<'de> Deserialize<'de> for ToolMetrics
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ToolMetrics
impl JsonSchema for ToolMetrics
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for ToolMetrics
impl Serialize for ToolMetrics
impl Copy for ToolMetrics