pub struct ModelUsageRow {
pub provider: String,
pub model: String,
pub request_count: i64,
pub total_tokens: i64,
pub total_cost_microdollars: i64,
pub avg_latency_ms: i64,
pub percentage: f64,
}Fields
provider: Stringmodel: Stringrequest_count: i64total_tokens: i64total_cost_microdollars: i64avg_latency_ms: i64percentage: f64Trait Implementations
Sourceimpl Clone for ModelUsageRow
impl Clone for ModelUsageRow
Sourcefn clone(&self) -> ModelUsageRow
fn clone(&self) -> ModelUsageRow
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ModelUsageRow
impl Debug for ModelUsageRow
Sourceimpl<'de> Deserialize<'de> for ModelUsageRow
impl<'de> Deserialize<'de> for ModelUsageRow
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ModelUsageRow
impl JsonSchema for ModelUsageRow
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ModelUsageRow
impl RefUnwindSafe for ModelUsageRow
impl Send for ModelUsageRow
impl Sync for ModelUsageRow
impl Unpin for ModelUsageRow
impl UnsafeUnpin for ModelUsageRow
impl UnwindSafe for ModelUsageRow