pub struct ModelsOutput {
pub period: String,
pub models: Vec<ModelUsageRow>,
pub total_requests: i64,
}Fields
period: Stringmodels: Vec<ModelUsageRow>total_requests: i64Trait Implementations
Sourceimpl Clone for ModelsOutput
impl Clone for ModelsOutput
Sourcefn clone(&self) -> ModelsOutput
fn clone(&self) -> ModelsOutput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ModelsOutput
impl Debug for ModelsOutput
Sourceimpl<'de> Deserialize<'de> for ModelsOutput
impl<'de> Deserialize<'de> for ModelsOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ModelsOutput
impl JsonSchema for ModelsOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ModelsOutput
impl RefUnwindSafe for ModelsOutput
impl Send for ModelsOutput
impl Sync for ModelsOutput
impl Unpin for ModelsOutput
impl UnsafeUnpin for ModelsOutput
impl UnwindSafe for ModelsOutput