pub struct RequestStatsOutput {
pub period: String,
pub total_requests: i64,
pub total_tokens: i64,
pub input_tokens: i64,
pub output_tokens: i64,
pub total_cost_microdollars: i64,
pub avg_latency_ms: i64,
pub cache_hit_rate: f64,
}Fields
period: Stringtotal_requests: i64total_tokens: i64input_tokens: i64output_tokens: i64total_cost_microdollars: i64avg_latency_ms: i64cache_hit_rate: f64Trait Implementations
Sourceimpl Clone for RequestStatsOutput
impl Clone for RequestStatsOutput
Sourcefn clone(&self) -> RequestStatsOutput
fn clone(&self) -> RequestStatsOutput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RequestStatsOutput
impl Debug for RequestStatsOutput
Sourceimpl<'de> Deserialize<'de> for RequestStatsOutput
impl<'de> Deserialize<'de> for RequestStatsOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RequestStatsOutput
impl JsonSchema for RequestStatsOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RequestStatsOutput
impl RefUnwindSafe for RequestStatsOutput
impl Send for RequestStatsOutput
impl Sync for RequestStatsOutput
impl Unpin for RequestStatsOutput
impl UnsafeUnpin for RequestStatsOutput
impl UnwindSafe for RequestStatsOutput