pub struct RequestsArgs {
pub cmd: Option<RequestsCommands>,
pub stats: StatsArgs,
}Expand description
analytics requests with no subcommand runs the stats aggregate.
That keeps the bare command runnable rather than a usage error. The stats arguments are flattened here, which leaves their clap defaults the single source of truth.
Fields
cmd: Option<RequestsCommands>stats: StatsArgsTrait Implementations
Sourceimpl Args for RequestsArgs
impl Args for RequestsArgs
Sourcefn augment_args<'b>(__clap_app: Command) -> Command
fn augment_args<'b>(__clap_app: Command) -> Command
Sourcefn augment_args_for_update<'b>(__clap_app: Command) -> Command
fn augment_args_for_update<'b>(__clap_app: Command) -> Command
Append to
Command so it can instantiate self via
FromArgMatches::update_from_arg_matches_mut Read moreSourceimpl Debug for RequestsArgs
impl Debug for RequestsArgs
Sourceimpl FromArgMatches for RequestsArgs
impl FromArgMatches for RequestsArgs
Sourcefn from_arg_matches(__clap_arg_matches: &ArgMatches) -> Result<Self, Error>
fn from_arg_matches(__clap_arg_matches: &ArgMatches) -> Result<Self, Error>
Sourcefn from_arg_matches_mut(
__clap_arg_matches: &mut ArgMatches,
) -> Result<Self, Error>
fn from_arg_matches_mut( __clap_arg_matches: &mut ArgMatches, ) -> Result<Self, Error>
Sourcefn update_from_arg_matches(
&mut self,
__clap_arg_matches: &ArgMatches,
) -> Result<(), Error>
fn update_from_arg_matches( &mut self, __clap_arg_matches: &ArgMatches, ) -> Result<(), Error>
Assign values from
ArgMatches to self.Sourcefn update_from_arg_matches_mut(
&mut self,
__clap_arg_matches: &mut ArgMatches,
) -> Result<(), Error>
fn update_from_arg_matches_mut( &mut self, __clap_arg_matches: &mut ArgMatches, ) -> Result<(), Error>
Assign values from
ArgMatches to self.Auto Trait Implementations
impl Freeze for RequestsArgs
impl RefUnwindSafe for RequestsArgs
impl Send for RequestsArgs
impl Sync for RequestsArgs
impl Unpin for RequestsArgs
impl UnsafeUnpin for RequestsArgs
impl UnwindSafe for RequestsArgs