pub struct ActiveSessionRow {
pub session_id: String,
pub user_type: String,
pub started_at: String,
pub duration_seconds: i64,
pub request_count: i64,
pub last_activity: String,
}Fields
session_id: Stringuser_type: Stringstarted_at: Stringduration_seconds: i64request_count: i64last_activity: StringTrait Implementations
Sourceimpl Clone for ActiveSessionRow
impl Clone for ActiveSessionRow
Sourcefn clone(&self) -> ActiveSessionRow
fn clone(&self) -> ActiveSessionRow
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ActiveSessionRow
impl Debug for ActiveSessionRow
Sourceimpl<'de> Deserialize<'de> for ActiveSessionRow
impl<'de> Deserialize<'de> for ActiveSessionRow
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ActiveSessionRow
impl JsonSchema for ActiveSessionRow
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ActiveSessionRow
impl RefUnwindSafe for ActiveSessionRow
impl Send for ActiveSessionRow
impl Sync for ActiveSessionRow
impl Unpin for ActiveSessionRow
impl UnsafeUnpin for ActiveSessionRow
impl UnwindSafe for ActiveSessionRow