pub struct LiveSessionsOutput {
pub active_count: i64,
pub sessions: Vec<ActiveSessionRow>,
pub timestamp: String,
}Fields
active_count: i64sessions: Vec<ActiveSessionRow>timestamp: StringTrait Implementations
Sourceimpl Clone for LiveSessionsOutput
impl Clone for LiveSessionsOutput
Sourcefn clone(&self) -> LiveSessionsOutput
fn clone(&self) -> LiveSessionsOutput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LiveSessionsOutput
impl Debug for LiveSessionsOutput
Sourceimpl<'de> Deserialize<'de> for LiveSessionsOutput
impl<'de> Deserialize<'de> for LiveSessionsOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for LiveSessionsOutput
impl JsonSchema for LiveSessionsOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for LiveSessionsOutput
impl RefUnwindSafe for LiveSessionsOutput
impl Send for LiveSessionsOutput
impl Sync for LiveSessionsOutput
impl Unpin for LiveSessionsOutput
impl UnsafeUnpin for LiveSessionsOutput
impl UnwindSafe for LiveSessionsOutput