pub struct SessionStatsOutput {
pub period: String,
pub total_sessions: i64,
pub active_sessions: i64,
pub unique_users: i64,
pub avg_duration_seconds: i64,
pub avg_requests_per_session: f64,
pub conversion_rate: f64,
}Fields
period: Stringtotal_sessions: i64active_sessions: i64unique_users: i64avg_duration_seconds: i64avg_requests_per_session: f64conversion_rate: f64Trait Implementations
Sourceimpl Clone for SessionStatsOutput
impl Clone for SessionStatsOutput
Sourcefn clone(&self) -> SessionStatsOutput
fn clone(&self) -> SessionStatsOutput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SessionStatsOutput
impl Debug for SessionStatsOutput
Sourceimpl<'de> Deserialize<'de> for SessionStatsOutput
impl<'de> Deserialize<'de> for SessionStatsOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SessionStatsOutput
impl JsonSchema for SessionStatsOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SessionStatsOutput
impl RefUnwindSafe for SessionStatsOutput
impl Send for SessionStatsOutput
impl Sync for SessionStatsOutput
impl Unpin for SessionStatsOutput
impl UnwindSafe for SessionStatsOutput