pub struct SessionTrendPoint {
pub timestamp: String,
pub session_count: i64,
pub active_users: i64,
pub avg_duration_seconds: i64,
}Fields
timestamp: Stringsession_count: i64active_users: i64avg_duration_seconds: i64Trait Implementations
Sourceimpl Clone for SessionTrendPoint
impl Clone for SessionTrendPoint
Sourcefn clone(&self) -> SessionTrendPoint
fn clone(&self) -> SessionTrendPoint
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SessionTrendPoint
impl Debug for SessionTrendPoint
Sourceimpl<'de> Deserialize<'de> for SessionTrendPoint
impl<'de> Deserialize<'de> for SessionTrendPoint
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SessionTrendPoint
impl JsonSchema for SessionTrendPoint
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SessionTrendPoint
impl RefUnwindSafe for SessionTrendPoint
impl Send for SessionTrendPoint
impl Sync for SessionTrendPoint
impl Unpin for SessionTrendPoint
impl UnwindSafe for SessionTrendPoint