pub struct StatsSummary {
pub total: i64,
pub change_percent: Option<f64>,
pub period: String,
}Fields
total: i64change_percent: Option<f64>period: StringTrait Implementations
Sourceimpl Clone for StatsSummary
impl Clone for StatsSummary
Sourcefn clone(&self) -> StatsSummary
fn clone(&self) -> StatsSummary
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StatsSummary
impl Debug for StatsSummary
Sourceimpl<'de> Deserialize<'de> for StatsSummary
impl<'de> Deserialize<'de> for StatsSummary
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for StatsSummary
impl JsonSchema for StatsSummary
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for StatsSummary
impl RefUnwindSafe for StatsSummary
impl Send for StatsSummary
impl Sync for StatsSummary
impl Unpin for StatsSummary
impl UnwindSafe for StatsSummary