pub struct TrendPoint {
pub timestamp: String,
pub value: f64,
pub label: Option<String>,
}Fields
timestamp: Stringvalue: f64label: Option<String>Trait Implementations
Sourceimpl Clone for TrendPoint
impl Clone for TrendPoint
Sourcefn clone(&self) -> TrendPoint
fn clone(&self) -> TrendPoint
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TrendPoint
impl Debug for TrendPoint
Sourceimpl<'de> Deserialize<'de> for TrendPoint
impl<'de> Deserialize<'de> for TrendPoint
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for TrendPoint
impl JsonSchema for TrendPoint
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for TrendPoint
impl RefUnwindSafe for TrendPoint
impl Send for TrendPoint
impl Sync for TrendPoint
impl Unpin for TrendPoint
impl UnwindSafe for TrendPoint