pub struct ToolListOutput {
pub tools: Vec<ToolListRow>,
pub total: i64,
}Fields
tools: Vec<ToolListRow>total: i64Trait Implementations
Sourceimpl Clone for ToolListOutput
impl Clone for ToolListOutput
Sourcefn clone(&self) -> ToolListOutput
fn clone(&self) -> ToolListOutput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ToolListOutput
impl Debug for ToolListOutput
Sourceimpl<'de> Deserialize<'de> for ToolListOutput
impl<'de> Deserialize<'de> for ToolListOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ToolListOutput
impl JsonSchema for ToolListOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ToolListOutput
impl RefUnwindSafe for ToolListOutput
impl Send for ToolListOutput
impl Sync for ToolListOutput
impl Unpin for ToolListOutput
impl UnwindSafe for ToolListOutput