pub struct ToolListRow {
pub tool_name: String,
pub server_name: String,
pub execution_count: i64,
pub success_rate: f64,
pub avg_execution_time_ms: i64,
pub last_used: String,
}Fields
tool_name: Stringserver_name: Stringexecution_count: i64success_rate: f64avg_execution_time_ms: i64last_used: StringTrait Implementations
Sourceimpl Clone for ToolListRow
impl Clone for ToolListRow
Sourcefn clone(&self) -> ToolListRow
fn clone(&self) -> ToolListRow
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ToolListRow
impl Debug for ToolListRow
Sourceimpl<'de> Deserialize<'de> for ToolListRow
impl<'de> Deserialize<'de> for ToolListRow
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ToolListRow
impl JsonSchema for ToolListRow
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ToolListRow
impl RefUnwindSafe for ToolListRow
impl Send for ToolListRow
impl Sync for ToolListRow
impl Unpin for ToolListRow
impl UnwindSafe for ToolListRow