pub struct ToolShowOutput {
pub tool_name: String,
pub period: String,
pub summary: ToolStatsOutput,
pub status_breakdown: Vec<StatusBreakdownItem>,
pub top_errors: Vec<ErrorItem>,
pub usage_by_agent: Vec<AgentUsageItem>,
}Fields
tool_name: Stringperiod: Stringsummary: ToolStatsOutputstatus_breakdown: Vec<StatusBreakdownItem>top_errors: Vec<ErrorItem>usage_by_agent: Vec<AgentUsageItem>Trait Implementations
Sourceimpl Clone for ToolShowOutput
impl Clone for ToolShowOutput
Sourcefn clone(&self) -> ToolShowOutput
fn clone(&self) -> ToolShowOutput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ToolShowOutput
impl Debug for ToolShowOutput
Sourceimpl<'de> Deserialize<'de> for ToolShowOutput
impl<'de> Deserialize<'de> for ToolShowOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ToolShowOutput
impl JsonSchema for ToolShowOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ToolShowOutput
impl RefUnwindSafe for ToolShowOutput
impl Send for ToolShowOutput
impl Sync for ToolShowOutput
impl Unpin for ToolShowOutput
impl UnsafeUnpin for ToolShowOutput
impl UnwindSafe for ToolShowOutput