pub struct ToolStatsOutput {
pub period: String,
pub total_tools: i64,
pub total_executions: i64,
pub successful: i64,
pub failed: i64,
pub timeout: i64,
pub success_rate: f64,
pub avg_execution_time_ms: i64,
pub p95_execution_time_ms: i64,
}Fields
period: Stringtotal_tools: i64total_executions: i64successful: i64failed: i64timeout: i64success_rate: f64avg_execution_time_ms: i64p95_execution_time_ms: i64Trait Implementations
Sourceimpl Clone for ToolStatsOutput
impl Clone for ToolStatsOutput
Sourcefn clone(&self) -> ToolStatsOutput
fn clone(&self) -> ToolStatsOutput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ToolStatsOutput
impl Debug for ToolStatsOutput
Sourceimpl<'de> Deserialize<'de> for ToolStatsOutput
impl<'de> Deserialize<'de> for ToolStatsOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ToolStatsOutput
impl JsonSchema for ToolStatsOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ToolStatsOutput
impl RefUnwindSafe for ToolStatsOutput
impl Send for ToolStatsOutput
impl Sync for ToolStatsOutput
impl Unpin for ToolStatsOutput
impl UnwindSafe for ToolStatsOutput