pub struct ToolTrendPoint {
pub timestamp: String,
pub execution_count: i64,
pub success_rate: f64,
pub avg_execution_time_ms: i64,
}Fields
timestamp: Stringexecution_count: i64success_rate: f64avg_execution_time_ms: i64Trait Implementations
Sourceimpl Clone for ToolTrendPoint
impl Clone for ToolTrendPoint
Sourcefn clone(&self) -> ToolTrendPoint
fn clone(&self) -> ToolTrendPoint
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ToolTrendPoint
impl Debug for ToolTrendPoint
Sourceimpl<'de> Deserialize<'de> for ToolTrendPoint
impl<'de> Deserialize<'de> for ToolTrendPoint
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ToolTrendPoint
impl JsonSchema for ToolTrendPoint
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ToolTrendPoint
impl RefUnwindSafe for ToolTrendPoint
impl Send for ToolTrendPoint
impl Sync for ToolTrendPoint
impl Unpin for ToolTrendPoint
impl UnsafeUnpin for ToolTrendPoint
impl UnwindSafe for ToolTrendPoint