pub struct ToolTrendsOutput {
pub tool: Option<String>,
pub period: String,
pub group_by: String,
pub points: Vec<ToolTrendPoint>,
}Fields
tool: Option<String>period: Stringgroup_by: Stringpoints: Vec<ToolTrendPoint>Trait Implementations
Sourceimpl Clone for ToolTrendsOutput
impl Clone for ToolTrendsOutput
Sourcefn clone(&self) -> ToolTrendsOutput
fn clone(&self) -> ToolTrendsOutput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ToolTrendsOutput
impl Debug for ToolTrendsOutput
Sourceimpl<'de> Deserialize<'de> for ToolTrendsOutput
impl<'de> Deserialize<'de> for ToolTrendsOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ToolTrendsOutput
impl JsonSchema for ToolTrendsOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ToolTrendsOutput
impl RefUnwindSafe for ToolTrendsOutput
impl Send for ToolTrendsOutput
impl Sync for ToolTrendsOutput
impl Unpin for ToolTrendsOutput
impl UnsafeUnpin for ToolTrendsOutput
impl UnwindSafe for ToolTrendsOutput