pub struct BotsOutput {
pub period: String,
pub human_sessions: i64,
pub bot_sessions: i64,
pub bot_percentage: f64,
pub bot_breakdown: Vec<BotRow>,
}Fields
period: Stringhuman_sessions: i64bot_sessions: i64bot_percentage: f64bot_breakdown: Vec<BotRow>Trait Implementations
Sourceimpl Clone for BotsOutput
impl Clone for BotsOutput
Sourcefn clone(&self) -> BotsOutput
fn clone(&self) -> BotsOutput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BotsOutput
impl Debug for BotsOutput
Sourceimpl<'de> Deserialize<'de> for BotsOutput
impl<'de> Deserialize<'de> for BotsOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for BotsOutput
impl JsonSchema for BotsOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for BotsOutput
impl RefUnwindSafe for BotsOutput
impl Send for BotsOutput
impl Sync for BotsOutput
impl Unpin for BotsOutput
impl UnwindSafe for BotsOutput