pub struct DevicesOutput {
pub period: String,
pub devices: Vec<DeviceRow>,
pub total_sessions: i64,
}Fields
period: Stringdevices: Vec<DeviceRow>total_sessions: i64Trait Implementations
Sourceimpl Clone for DevicesOutput
impl Clone for DevicesOutput
Sourcefn clone(&self) -> DevicesOutput
fn clone(&self) -> DevicesOutput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DevicesOutput
impl Debug for DevicesOutput
Sourceimpl<'de> Deserialize<'de> for DevicesOutput
impl<'de> Deserialize<'de> for DevicesOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for DevicesOutput
impl JsonSchema for DevicesOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for DevicesOutput
impl RefUnwindSafe for DevicesOutput
impl Send for DevicesOutput
impl Sync for DevicesOutput
impl Unpin for DevicesOutput
impl UnwindSafe for DevicesOutput