pub struct GeoRow {
pub country: String,
pub session_count: i64,
pub percentage: f64,
}Fields
country: Stringsession_count: i64percentage: f64Trait Implementations
Sourceimpl<'de> Deserialize<'de> for GeoRow
impl<'de> Deserialize<'de> for GeoRow
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for GeoRow
impl JsonSchema for GeoRow
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for GeoRow
impl RefUnwindSafe for GeoRow
impl Send for GeoRow
impl Sync for GeoRow
impl Unpin for GeoRow
impl UnsafeUnpin for GeoRow
impl UnwindSafe for GeoRow