pub struct TrafficSourceRow {
pub source: String,
pub session_count: i64,
pub percentage: f64,
}Fields
source: Stringsession_count: i64percentage: f64Trait Implementations
Sourceimpl Clone for TrafficSourceRow
impl Clone for TrafficSourceRow
Sourcefn clone(&self) -> TrafficSourceRow
fn clone(&self) -> TrafficSourceRow
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TrafficSourceRow
impl Debug for TrafficSourceRow
Sourceimpl<'de> Deserialize<'de> for TrafficSourceRow
impl<'de> Deserialize<'de> for TrafficSourceRow
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for TrafficSourceRow
impl JsonSchema for TrafficSourceRow
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for TrafficSourceRow
impl RefUnwindSafe for TrafficSourceRow
impl Send for TrafficSourceRow
impl Sync for TrafficSourceRow
impl Unpin for TrafficSourceRow
impl UnsafeUnpin for TrafficSourceRow
impl UnwindSafe for TrafficSourceRow