pub struct TrafficSourcesOutput {
pub period: String,
pub sources: Vec<TrafficSourceRow>,
pub total_sessions: i64,
}Fields
period: Stringsources: Vec<TrafficSourceRow>total_sessions: i64Trait Implementations
Sourceimpl Clone for TrafficSourcesOutput
impl Clone for TrafficSourcesOutput
Sourcefn clone(&self) -> TrafficSourcesOutput
fn clone(&self) -> TrafficSourcesOutput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TrafficSourcesOutput
impl Debug for TrafficSourcesOutput
Sourceimpl<'de> Deserialize<'de> for TrafficSourcesOutput
impl<'de> Deserialize<'de> for TrafficSourcesOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for TrafficSourcesOutput
impl JsonSchema for TrafficSourcesOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for TrafficSourcesOutput
impl RefUnwindSafe for TrafficSourcesOutput
impl Send for TrafficSourcesOutput
impl Sync for TrafficSourcesOutput
impl Unpin for TrafficSourcesOutput
impl UnsafeUnpin for TrafficSourcesOutput
impl UnwindSafe for TrafficSourcesOutput