pub struct BuildExtensionRow {
pub name: String,
pub build_type: String,
pub status: String,
}Fields
name: Stringbuild_type: Stringstatus: StringTrait Implementations
Sourceimpl Clone for BuildExtensionRow
impl Clone for BuildExtensionRow
Sourcefn clone(&self) -> BuildExtensionRow
fn clone(&self) -> BuildExtensionRow
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BuildExtensionRow
impl Debug for BuildExtensionRow
Sourceimpl<'de> Deserialize<'de> for BuildExtensionRow
impl<'de> Deserialize<'de> for BuildExtensionRow
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for BuildExtensionRow
impl JsonSchema for BuildExtensionRow
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for BuildExtensionRow
impl RefUnwindSafe for BuildExtensionRow
impl Send for BuildExtensionRow
impl Sync for BuildExtensionRow
impl Unpin for BuildExtensionRow
impl UnwindSafe for BuildExtensionRow