pub struct BuildOutput {
pub extensions: Vec<BuildExtensionRow>,
pub total: usize,
pub successful: usize,
pub release_mode: bool,
}Fields
extensions: Vec<BuildExtensionRow>total: usizesuccessful: usizerelease_mode: boolTrait Implementations
Sourceimpl Clone for BuildOutput
impl Clone for BuildOutput
Sourcefn clone(&self) -> BuildOutput
fn clone(&self) -> BuildOutput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BuildOutput
impl Debug for BuildOutput
Sourceimpl<'de> Deserialize<'de> for BuildOutput
impl<'de> Deserialize<'de> for BuildOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for BuildOutput
impl JsonSchema for BuildOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for BuildOutput
impl RefUnwindSafe for BuildOutput
impl Send for BuildOutput
impl Sync for BuildOutput
impl Unpin for BuildOutput
impl UnwindSafe for BuildOutput