Module init

Module init 

cloud init project scaffolding.

Creates the .systemprompt/ directory with its ignore files, Dockerfile, and entrypoint, and generates the default services/ boilerplate for a new project.

Copyright (c) systemprompt.io — Business Source License 1.1. See https://systemprompt.io for licensing details.

Modules

templates
Default file contents used when scaffolding a new project.