Module templates

Module templates 

Default file contents used when scaffolding a new project.

Each function returns the body of one generated service config, web template, or starter content file written by super::scaffolding.

Copyright (c) systemprompt.io — Business Source License 1.1. See https://systemprompt.io for licensing details.

Functions

admin_agent_config
admin_mcp_config
agent_config
ai_config
blog_list_template
blog_post_template
content_config
cookie_policy
page_list_template
page_template
privacy_policy
root_config
scheduler_config
web_config
web_metadata
welcome_blog_post