Module profile_steps

Module profile_steps 

Shared steps for building a profile from a stored tenant.

Provides create_profile_for_tenant and the helpers that resolve a tenant from CLI args and refresh masked cloud database credentials before a profile is written.

Copyright (c) systemprompt.io — Business Source License 1.1. See https://systemprompt.io for licensing details.

Structs

CreatedProfile

Functions

create_profile_for_tenant
ensure_unmasked_credentials
resolve_tenant_from_args
write_profile_secrets