pub struct AdminUserSyncResultOutput {
pub profile: String,
pub success: bool,
pub message: Option<String>,
pub error: Option<String>,
}Fields
profile: Stringsuccess: boolmessage: Option<String>error: Option<String>Trait Implementations
Sourceimpl Clone for AdminUserSyncResultOutput
impl Clone for AdminUserSyncResultOutput
Sourcefn clone(&self) -> AdminUserSyncResultOutput
fn clone(&self) -> AdminUserSyncResultOutput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AdminUserSyncResultOutput
impl Debug for AdminUserSyncResultOutput
Sourceimpl<'de> Deserialize<'de> for AdminUserSyncResultOutput
impl<'de> Deserialize<'de> for AdminUserSyncResultOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AdminUserSyncResultOutput
impl JsonSchema for AdminUserSyncResultOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AdminUserSyncResultOutput
impl RefUnwindSafe for AdminUserSyncResultOutput
impl Send for AdminUserSyncResultOutput
impl Sync for AdminUserSyncResultOutput
impl Unpin for AdminUserSyncResultOutput
impl UnsafeUnpin for AdminUserSyncResultOutput
impl UnwindSafe for AdminUserSyncResultOutput