pub struct CancelSubscriptionOutput {
pub tenant_id: String,
pub tenant_name: String,
pub message: String,
}Fields
tenant_id: Stringtenant_name: Stringmessage: StringTrait Implementations
Sourceimpl Clone for CancelSubscriptionOutput
impl Clone for CancelSubscriptionOutput
Sourcefn clone(&self) -> CancelSubscriptionOutput
fn clone(&self) -> CancelSubscriptionOutput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CancelSubscriptionOutput
impl Debug for CancelSubscriptionOutput
Sourceimpl<'de> Deserialize<'de> for CancelSubscriptionOutput
impl<'de> Deserialize<'de> for CancelSubscriptionOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CancelSubscriptionOutput
impl JsonSchema for CancelSubscriptionOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for CancelSubscriptionOutput
impl RefUnwindSafe for CancelSubscriptionOutput
impl Send for CancelSubscriptionOutput
impl Sync for CancelSubscriptionOutput
impl Unpin for CancelSubscriptionOutput
impl UnwindSafe for CancelSubscriptionOutput