pub struct CloudStatusOutput {
pub profile: Option<ProfileInfo>,
pub credentials: CredentialsInfo,
pub tenants: Vec<TenantStatusInfo>,
}Fields
profile: Option<ProfileInfo>credentials: CredentialsInfotenants: Vec<TenantStatusInfo>Trait Implementations
Sourceimpl Clone for CloudStatusOutput
impl Clone for CloudStatusOutput
Sourcefn clone(&self) -> CloudStatusOutput
fn clone(&self) -> CloudStatusOutput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CloudStatusOutput
impl Debug for CloudStatusOutput
Sourceimpl<'de> Deserialize<'de> for CloudStatusOutput
impl<'de> Deserialize<'de> for CloudStatusOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CloudStatusOutput
impl JsonSchema for CloudStatusOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for CloudStatusOutput
impl RefUnwindSafe for CloudStatusOutput
impl Send for CloudStatusOutput
impl Sync for CloudStatusOutput
impl Unpin for CloudStatusOutput
impl UnsafeUnpin for CloudStatusOutput
impl UnwindSafe for CloudStatusOutput