pub struct CredentialsInfo {
pub authenticated: bool,
pub user_email: Option<String>,
pub token_expired: bool,
}Fields
authenticated: booluser_email: Option<String>token_expired: boolTrait Implementations
Sourceimpl Clone for CredentialsInfo
impl Clone for CredentialsInfo
Sourcefn clone(&self) -> CredentialsInfo
fn clone(&self) -> CredentialsInfo
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CredentialsInfo
impl Debug for CredentialsInfo
Sourceimpl<'de> Deserialize<'de> for CredentialsInfo
impl<'de> Deserialize<'de> for CredentialsInfo
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CredentialsInfo
impl JsonSchema for CredentialsInfo
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for CredentialsInfo
impl RefUnwindSafe for CredentialsInfo
impl Send for CredentialsInfo
impl Sync for CredentialsInfo
impl Unpin for CredentialsInfo
impl UnsafeUnpin for CredentialsInfo
impl UnwindSafe for CredentialsInfo