pub struct DeployOutput {
pub tenant_name: String,
pub image: String,
pub status: String,
pub url: Option<String>,
pub secrets_synced: usize,
pub cloud_credentials_synced: usize,
}Fields
tenant_name: Stringimage: Stringstatus: Stringurl: Option<String>secrets_synced: usizecloud_credentials_synced: usizeTrait Implementations
Sourceimpl Clone for DeployOutput
impl Clone for DeployOutput
Sourcefn clone(&self) -> DeployOutput
fn clone(&self) -> DeployOutput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DeployOutput
impl Debug for DeployOutput
Sourceimpl<'de> Deserialize<'de> for DeployOutput
impl<'de> Deserialize<'de> for DeployOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for DeployOutput
impl JsonSchema for DeployOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for DeployOutput
impl RefUnwindSafe for DeployOutput
impl Send for DeployOutput
impl Sync for DeployOutput
impl Unpin for DeployOutput
impl UnsafeUnpin for DeployOutput
impl UnwindSafe for DeployOutput