pub struct DockerfileOutput {
pub content: String,
}Fields
content: StringTrait Implementations
Sourceimpl Clone for DockerfileOutput
impl Clone for DockerfileOutput
Sourcefn clone(&self) -> DockerfileOutput
fn clone(&self) -> DockerfileOutput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DockerfileOutput
impl Debug for DockerfileOutput
Sourceimpl<'de> Deserialize<'de> for DockerfileOutput
impl<'de> Deserialize<'de> for DockerfileOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for DockerfileOutput
impl JsonSchema for DockerfileOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for DockerfileOutput
impl RefUnwindSafe for DockerfileOutput
impl Send for DockerfileOutput
impl Sync for DockerfileOutput
impl Unpin for DockerfileOutput
impl UnsafeUnpin for DockerfileOutput
impl UnwindSafe for DockerfileOutput