pub struct DomainOutput {
pub tenant_name: String,
pub domain: String,
pub status: String,
pub certificate_status: Option<String>,
}Fields
tenant_name: Stringdomain: Stringstatus: Stringcertificate_status: Option<String>Trait Implementations
Sourceimpl Clone for DomainOutput
impl Clone for DomainOutput
Sourcefn clone(&self) -> DomainOutput
fn clone(&self) -> DomainOutput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DomainOutput
impl Debug for DomainOutput
Sourceimpl<'de> Deserialize<'de> for DomainOutput
impl<'de> Deserialize<'de> for DomainOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for DomainOutput
impl JsonSchema for DomainOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for DomainOutput
impl RefUnwindSafe for DomainOutput
impl Send for DomainOutput
impl Sync for DomainOutput
impl Unpin for DomainOutput
impl UnsafeUnpin for DomainOutput
impl UnwindSafe for DomainOutput