pub struct InitOutput {
pub message: String,
pub created_paths: Vec<String>,
}Fields
message: Stringcreated_paths: Vec<String>Trait Implementations
Sourceimpl Clone for InitOutput
impl Clone for InitOutput
Sourcefn clone(&self) -> InitOutput
fn clone(&self) -> InitOutput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for InitOutput
impl Debug for InitOutput
Sourceimpl<'de> Deserialize<'de> for InitOutput
impl<'de> Deserialize<'de> for InitOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for InitOutput
impl JsonSchema for InitOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for InitOutput
impl RefUnwindSafe for InitOutput
impl Send for InitOutput
impl Sync for InitOutput
impl Unpin for InitOutput
impl UnsafeUnpin for InitOutput
impl UnwindSafe for InitOutput