pub struct LoginOutput {
pub user: LoginUserInfo,
pub customer: Option<LoginCustomerInfo>,
pub tenants: Vec<LoginTenantInfo>,
pub credentials_path: String,
pub tenants_path: String,
}Fields
user: LoginUserInfocustomer: Option<LoginCustomerInfo>tenants: Vec<LoginTenantInfo>credentials_path: Stringtenants_path: StringTrait Implementations
Sourceimpl Clone for LoginOutput
impl Clone for LoginOutput
Sourcefn clone(&self) -> LoginOutput
fn clone(&self) -> LoginOutput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LoginOutput
impl Debug for LoginOutput
Sourceimpl<'de> Deserialize<'de> for LoginOutput
impl<'de> Deserialize<'de> for LoginOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for LoginOutput
impl JsonSchema for LoginOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for LoginOutput
impl RefUnwindSafe for LoginOutput
impl Send for LoginOutput
impl Sync for LoginOutput
impl Unpin for LoginOutput
impl UnwindSafe for LoginOutput