pub struct LoginTenantInfo {
pub id: String,
pub name: String,
pub subscription_status: Option<String>,
pub plan: Option<TenantPlanInfo>,
pub region: Option<String>,
pub hostname: Option<String>,
}Fields
id: Stringname: Stringsubscription_status: Option<String>plan: Option<TenantPlanInfo>region: Option<String>hostname: Option<String>Trait Implementations
Sourceimpl Clone for LoginTenantInfo
impl Clone for LoginTenantInfo
Sourcefn clone(&self) -> LoginTenantInfo
fn clone(&self) -> LoginTenantInfo
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LoginTenantInfo
impl Debug for LoginTenantInfo
Sourceimpl<'de> Deserialize<'de> for LoginTenantInfo
impl<'de> Deserialize<'de> for LoginTenantInfo
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for LoginTenantInfo
impl JsonSchema for LoginTenantInfo
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for LoginTenantInfo
impl RefUnwindSafe for LoginTenantInfo
impl Send for LoginTenantInfo
impl Sync for LoginTenantInfo
impl Unpin for LoginTenantInfo
impl UnsafeUnpin for LoginTenantInfo
impl UnwindSafe for LoginTenantInfo