pub struct LoginUserInfo {
pub id: String,
pub email: String,
pub name: Option<String>,
}Fields
id: Stringemail: Stringname: Option<String>Trait Implementations
Sourceimpl Clone for LoginUserInfo
impl Clone for LoginUserInfo
Sourcefn clone(&self) -> LoginUserInfo
fn clone(&self) -> LoginUserInfo
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LoginUserInfo
impl Debug for LoginUserInfo
Sourceimpl<'de> Deserialize<'de> for LoginUserInfo
impl<'de> Deserialize<'de> for LoginUserInfo
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for LoginUserInfo
impl JsonSchema for LoginUserInfo
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for LoginUserInfo
impl RefUnwindSafe for LoginUserInfo
impl Send for LoginUserInfo
impl Sync for LoginUserInfo
impl Unpin for LoginUserInfo
impl UnsafeUnpin for LoginUserInfo
impl UnwindSafe for LoginUserInfo