pub struct LogoutOutput {
pub message: String,
pub credentials_path: Option<String>,
}Fields
message: Stringcredentials_path: Option<String>Trait Implementations
Sourceimpl Clone for LogoutOutput
impl Clone for LogoutOutput
Sourcefn clone(&self) -> LogoutOutput
fn clone(&self) -> LogoutOutput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LogoutOutput
impl Debug for LogoutOutput
Sourceimpl<'de> Deserialize<'de> for LogoutOutput
impl<'de> Deserialize<'de> for LogoutOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for LogoutOutput
impl JsonSchema for LogoutOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for LogoutOutput
impl RefUnwindSafe for LogoutOutput
impl Send for LogoutOutput
impl Sync for LogoutOutput
impl Unpin for LogoutOutput
impl UnsafeUnpin for LogoutOutput
impl UnwindSafe for LogoutOutput