pub struct ProfileInfo {
pub name: String,
pub display_name: String,
pub tenant_id: Option<String>,
pub validation_mode: Option<String>,
pub credentials_path: Option<String>,
}Fields
name: Stringdisplay_name: Stringtenant_id: Option<String>validation_mode: Option<String>credentials_path: Option<String>Trait Implementations
Sourceimpl Clone for ProfileInfo
impl Clone for ProfileInfo
Sourcefn clone(&self) -> ProfileInfo
fn clone(&self) -> ProfileInfo
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProfileInfo
impl Debug for ProfileInfo
Sourceimpl<'de> Deserialize<'de> for ProfileInfo
impl<'de> Deserialize<'de> for ProfileInfo
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ProfileInfo
impl JsonSchema for ProfileInfo
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ProfileInfo
impl RefUnwindSafe for ProfileInfo
impl Send for ProfileInfo
impl Sync for ProfileInfo
impl Unpin for ProfileInfo
impl UnsafeUnpin for ProfileInfo
impl UnwindSafe for ProfileInfo