pub struct ProfileSummary {
pub name: String,
pub has_secrets: bool,
pub is_active: bool,
}Fields
name: Stringhas_secrets: boolis_active: boolTrait Implementations
Sourceimpl Clone for ProfileSummary
impl Clone for ProfileSummary
Sourcefn clone(&self) -> ProfileSummary
fn clone(&self) -> ProfileSummary
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProfileSummary
impl Debug for ProfileSummary
Sourceimpl<'de> Deserialize<'de> for ProfileSummary
impl<'de> Deserialize<'de> for ProfileSummary
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ProfileSummary
impl JsonSchema for ProfileSummary
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ProfileSummary
impl RefUnwindSafe for ProfileSummary
impl Send for ProfileSummary
impl Sync for ProfileSummary
impl Unpin for ProfileSummary
impl UnsafeUnpin for ProfileSummary
impl UnwindSafe for ProfileSummary