pub struct RestartOutput {
pub tenant_name: String,
pub status: String,
}Fields
tenant_name: Stringstatus: StringTrait Implementations
Sourceimpl Clone for RestartOutput
impl Clone for RestartOutput
Sourcefn clone(&self) -> RestartOutput
fn clone(&self) -> RestartOutput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RestartOutput
impl Debug for RestartOutput
Sourceimpl<'de> Deserialize<'de> for RestartOutput
impl<'de> Deserialize<'de> for RestartOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RestartOutput
impl JsonSchema for RestartOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RestartOutput
impl RefUnwindSafe for RestartOutput
impl Send for RestartOutput
impl Sync for RestartOutput
impl Unpin for RestartOutput
impl UnwindSafe for RestartOutput