pub struct RotateCredentialsOutput {
pub tenant_id: String,
pub status: String,
pub internal_database_url: String,
pub external_database_url: String,
}Fields
tenant_id: Stringstatus: Stringinternal_database_url: Stringexternal_database_url: StringTrait Implementations
Sourceimpl Clone for RotateCredentialsOutput
impl Clone for RotateCredentialsOutput
Sourcefn clone(&self) -> RotateCredentialsOutput
fn clone(&self) -> RotateCredentialsOutput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RotateCredentialsOutput
impl Debug for RotateCredentialsOutput
Sourceimpl<'de> Deserialize<'de> for RotateCredentialsOutput
impl<'de> Deserialize<'de> for RotateCredentialsOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RotateCredentialsOutput
impl JsonSchema for RotateCredentialsOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RotateCredentialsOutput
impl RefUnwindSafe for RotateCredentialsOutput
impl Send for RotateCredentialsOutput
impl Sync for RotateCredentialsOutput
impl Unpin for RotateCredentialsOutput
impl UnwindSafe for RotateCredentialsOutput