pub struct SecretsOutput {
pub operation: String,
pub keys: Vec<String>,
pub rejected_keys: Option<Vec<String>>,
}Fields
operation: Stringkeys: Vec<String>rejected_keys: Option<Vec<String>>Trait Implementations
Sourceimpl Clone for SecretsOutput
impl Clone for SecretsOutput
Sourcefn clone(&self) -> SecretsOutput
fn clone(&self) -> SecretsOutput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SecretsOutput
impl Debug for SecretsOutput
Sourceimpl<'de> Deserialize<'de> for SecretsOutput
impl<'de> Deserialize<'de> for SecretsOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SecretsOutput
impl JsonSchema for SecretsOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SecretsOutput
impl RefUnwindSafe for SecretsOutput
impl Send for SecretsOutput
impl Sync for SecretsOutput
impl Unpin for SecretsOutput
impl UnwindSafe for SecretsOutput