pub struct SkillsSyncOutput {
pub direction: String,
pub dry_run: bool,
pub synced: usize,
pub created: usize,
pub updated: usize,
pub deleted: usize,
pub errors: Vec<String>,
}Fields
direction: Stringdry_run: boolsynced: usizecreated: usizeupdated: usizedeleted: usizeerrors: Vec<String>Trait Implementations
Sourceimpl Clone for SkillsSyncOutput
impl Clone for SkillsSyncOutput
Sourcefn clone(&self) -> SkillsSyncOutput
fn clone(&self) -> SkillsSyncOutput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SkillsSyncOutput
impl Debug for SkillsSyncOutput
Sourceimpl<'de> Deserialize<'de> for SkillsSyncOutput
impl<'de> Deserialize<'de> for SkillsSyncOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SkillsSyncOutput
impl JsonSchema for SkillsSyncOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SkillsSyncOutput
impl RefUnwindSafe for SkillsSyncOutput
impl Send for SkillsSyncOutput
impl Sync for SkillsSyncOutput
impl Unpin for SkillsSyncOutput
impl UnsafeUnpin for SkillsSyncOutput
impl UnwindSafe for SkillsSyncOutput