pub struct SyncOutput {
pub direction: String,
pub dry_run: bool,
pub operations: Vec<SyncOperationOutput>,
}Fields
direction: Stringdry_run: booloperations: Vec<SyncOperationOutput>Trait Implementations
Sourceimpl Clone for SyncOutput
impl Clone for SyncOutput
Sourcefn clone(&self) -> SyncOutput
fn clone(&self) -> SyncOutput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SyncOutput
impl Debug for SyncOutput
Sourceimpl<'de> Deserialize<'de> for SyncOutput
impl<'de> Deserialize<'de> for SyncOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SyncOutput
impl JsonSchema for SyncOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SyncOutput
impl RefUnwindSafe for SyncOutput
impl Send for SyncOutput
impl Sync for SyncOutput
impl Unpin for SyncOutput
impl UnsafeUnpin for SyncOutput
impl UnwindSafe for SyncOutput