pub struct TenantDetailOutput {
pub id: String,
pub name: String,
pub tenant_type: String,
pub app_id: Option<String>,
pub hostname: Option<String>,
pub region: Option<String>,
pub has_database: bool,
}Fields
id: Stringname: Stringtenant_type: Stringapp_id: Option<String>hostname: Option<String>region: Option<String>has_database: boolTrait Implementations
Sourceimpl Clone for TenantDetailOutput
impl Clone for TenantDetailOutput
Sourcefn clone(&self) -> TenantDetailOutput
fn clone(&self) -> TenantDetailOutput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TenantDetailOutput
impl Debug for TenantDetailOutput
Sourceimpl<'de> Deserialize<'de> for TenantDetailOutput
impl<'de> Deserialize<'de> for TenantDetailOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for TenantDetailOutput
impl JsonSchema for TenantDetailOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for TenantDetailOutput
impl RefUnwindSafe for TenantDetailOutput
impl Send for TenantDetailOutput
impl Sync for TenantDetailOutput
impl Unpin for TenantDetailOutput
impl UnsafeUnpin for TenantDetailOutput
impl UnwindSafe for TenantDetailOutput