pub struct TenantStatusInfo {
pub id: String,
pub name: String,
pub status: String,
pub url: Option<String>,
pub message: Option<String>,
pub configured_in_profile: bool,
}Fields
id: Stringname: Stringstatus: Stringurl: Option<String>message: Option<String>configured_in_profile: boolTrait Implementations
Sourceimpl Clone for TenantStatusInfo
impl Clone for TenantStatusInfo
Sourcefn clone(&self) -> TenantStatusInfo
fn clone(&self) -> TenantStatusInfo
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TenantStatusInfo
impl Debug for TenantStatusInfo
Sourceimpl<'de> Deserialize<'de> for TenantStatusInfo
impl<'de> Deserialize<'de> for TenantStatusInfo
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for TenantStatusInfo
impl JsonSchema for TenantStatusInfo
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for TenantStatusInfo
impl RefUnwindSafe for TenantStatusInfo
impl Send for TenantStatusInfo
impl Sync for TenantStatusInfo
impl Unpin for TenantStatusInfo
impl UnsafeUnpin for TenantStatusInfo
impl UnwindSafe for TenantStatusInfo