pub struct TenantSummary {
pub id: String,
pub name: String,
pub tenant_type: String,
pub has_database: bool,
}Fields
id: Stringname: Stringtenant_type: Stringhas_database: boolTrait Implementations
Sourceimpl Clone for TenantSummary
impl Clone for TenantSummary
Sourcefn clone(&self) -> TenantSummary
fn clone(&self) -> TenantSummary
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TenantSummary
impl Debug for TenantSummary
Sourceimpl<'de> Deserialize<'de> for TenantSummary
impl<'de> Deserialize<'de> for TenantSummary
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for TenantSummary
impl JsonSchema for TenantSummary
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for TenantSummary
impl RefUnwindSafe for TenantSummary
impl Send for TenantSummary
impl Sync for TenantSummary
impl Unpin for TenantSummary
impl UnsafeUnpin for TenantSummary
impl UnwindSafe for TenantSummary