pub struct WhoamiOutput {
pub user_email: String,
pub api_url: String,
pub token_status: String,
pub authenticated_at: DateTime<Utc>,
pub local_profiles: usize,
pub cloud_tenants: usize,
}Fields
user_email: Stringapi_url: Stringtoken_status: Stringauthenticated_at: DateTime<Utc>local_profiles: usizecloud_tenants: usizeTrait Implementations
Sourceimpl Clone for WhoamiOutput
impl Clone for WhoamiOutput
Sourcefn clone(&self) -> WhoamiOutput
fn clone(&self) -> WhoamiOutput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for WhoamiOutput
impl Debug for WhoamiOutput
Sourceimpl<'de> Deserialize<'de> for WhoamiOutput
impl<'de> Deserialize<'de> for WhoamiOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for WhoamiOutput
impl JsonSchema for WhoamiOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for WhoamiOutput
impl RefUnwindSafe for WhoamiOutput
impl Send for WhoamiOutput
impl Sync for WhoamiOutput
impl Unpin for WhoamiOutput
impl UnsafeUnpin for WhoamiOutput
impl UnwindSafe for WhoamiOutput