pub struct ClientEvidenceOutput {
pub kind_source: String,
pub attested_host: Option<String>,
pub declared_client: Option<String>,
pub native_marker: Option<String>,
pub ua_product: Option<String>,
pub ua_version: Option<String>,
pub sdk_lang: Option<String>,
pub sdk_package_version: Option<String>,
pub sdk_runtime: Option<String>,
pub sdk_runtime_version: Option<String>,
pub sdk_os: Option<String>,
pub sdk_arch: Option<String>,
}Expand description
Only the evidence the wire presented is rendered; a field the request did not carry is omitted rather than shown empty.
Fields
kind_source: Stringattested_host: Option<String>declared_client: Option<String>native_marker: Option<String>ua_product: Option<String>ua_version: Option<String>sdk_lang: Option<String>sdk_package_version: Option<String>sdk_runtime: Option<String>sdk_runtime_version: Option<String>sdk_os: Option<String>sdk_arch: Option<String>Trait Implementations
Sourceimpl Clone for ClientEvidenceOutput
impl Clone for ClientEvidenceOutput
Sourcefn clone(&self) -> ClientEvidenceOutput
fn clone(&self) -> ClientEvidenceOutput
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ClientEvidenceOutput
impl Debug for ClientEvidenceOutput
Sourceimpl<'de> Deserialize<'de> for ClientEvidenceOutput
impl<'de> Deserialize<'de> for ClientEvidenceOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<AiRequestClientEvidence> for ClientEvidenceOutput
impl From<AiRequestClientEvidence> for ClientEvidenceOutput
Sourcefn from(evidence: AiRequestClientEvidence) -> Self
fn from(evidence: AiRequestClientEvidence) -> Self
Converts to this type from the input type.
Sourceimpl JsonSchema for ClientEvidenceOutput
impl JsonSchema for ClientEvidenceOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ClientEvidenceOutput
impl RefUnwindSafe for ClientEvidenceOutput
impl Send for ClientEvidenceOutput
impl Sync for ClientEvidenceOutput
impl Unpin for ClientEvidenceOutput
impl UnsafeUnpin for ClientEvidenceOutput
impl UnwindSafe for ClientEvidenceOutput