Module shared

Module shared 

Helpers shared across command groups.

Currently exposes the ValidationIssue / ValidationOutput result shapes used by the various validate subcommands.

Copyright (c) systemprompt.io — Business Source License 1.1. See https://systemprompt.io for licensing details.

Modules

mcp_tools
MCP tool probing shared by admin agents tools and plugins mcp tools.

Structs

ValidationIssue
ValidationOutput