Module types

Module types 

Serializable output types for the web command group.

These structs and enums are the rendered payloads (JSON/YAML/table) for the content-type, template, asset, and sitemap subcommands, plus the shared validation output re-exported here.

Copyright (c) systemprompt.io — Business Source License 1.1. See https://systemprompt.io for licensing details.

Re-exports

pub use crate::commands::shared::ValidationIssue;
pub use crate::commands::shared::ValidationOutput;

Structs

AssetDetailOutput
AssetSummary
BrandingInfo
ContentTypeCreateOutput
ContentTypeDeleteOutput
ContentTypeDetailOutput
ContentTypeEditOutput
ContentTypeSummary
IndexingInfo
ParentRouteInfo
SitemapGenerateOutput
SitemapInfo
SitemapRoute
TemplateCreateOutput
TemplateDeleteOutput
TemplateDetailOutput
TemplateEditOutput
TemplateEntry
TemplateSummary
TemplatesConfig

Enums

AssetType