pub struct ArtifactDetailOutput {Show 15 fields
pub id: String,
pub name: Option<String>,
pub description: Option<String>,
pub artifact_type: String,
pub tool_name: Option<String>,
pub source: Option<String>,
pub task_id: String,
pub context_id: String,
pub skill_id: Option<String>,
pub skill_name: Option<String>,
pub mcp_execution_id: Option<String>,
pub fingerprint: Option<String>,
pub created_at: String,
pub parts: Vec<ArtifactPartOutput>,
pub rendering_hints: Option<Value>,
}Fields
id: Stringname: Option<String>description: Option<String>artifact_type: Stringtool_name: Option<String>source: Option<String>task_id: Stringcontext_id: Stringskill_id: Option<String>skill_name: Option<String>mcp_execution_id: Option<String>fingerprint: Option<String>created_at: Stringparts: Vec<ArtifactPartOutput>rendering_hints: Option<Value>Trait Implementations
Sourceimpl Clone for ArtifactDetailOutput
impl Clone for ArtifactDetailOutput
Sourcefn clone(&self) -> ArtifactDetailOutput
fn clone(&self) -> ArtifactDetailOutput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ArtifactDetailOutput
impl Debug for ArtifactDetailOutput
Sourceimpl<'de> Deserialize<'de> for ArtifactDetailOutput
impl<'de> Deserialize<'de> for ArtifactDetailOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ArtifactDetailOutput
impl JsonSchema for ArtifactDetailOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ArtifactDetailOutput
impl RefUnwindSafe for ArtifactDetailOutput
impl Send for ArtifactDetailOutput
impl Sync for ArtifactDetailOutput
impl Unpin for ArtifactDetailOutput
impl UnsafeUnpin for ArtifactDetailOutput
impl UnwindSafe for ArtifactDetailOutput