pub struct ArtifactListOutput {
pub artifacts: Vec<ArtifactSummary>,
pub total: usize,
pub context_id: Option<String>,
}Fields
artifacts: Vec<ArtifactSummary>total: usizecontext_id: Option<String>Trait Implementations
Sourceimpl Clone for ArtifactListOutput
impl Clone for ArtifactListOutput
Sourcefn clone(&self) -> ArtifactListOutput
fn clone(&self) -> ArtifactListOutput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ArtifactListOutput
impl Debug for ArtifactListOutput
Sourceimpl<'de> Deserialize<'de> for ArtifactListOutput
impl<'de> Deserialize<'de> for ArtifactListOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ArtifactListOutput
impl JsonSchema for ArtifactListOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ArtifactListOutput
impl RefUnwindSafe for ArtifactListOutput
impl Send for ArtifactListOutput
impl Sync for ArtifactListOutput
impl Unpin for ArtifactListOutput
impl UnwindSafe for ArtifactListOutput