Module files

Module files 

core content files command group: associate stored files with content.

Dispatches the ContentFilesCommands subcommands (link, unlink, list, featured) that manage the content-to-file relationships and the featured image for a content item.

Copyright (c) systemprompt.io — Business Source License 1.1. See https://systemprompt.io for licensing details.

Modules

featured
core content files featured command setting the featured image.
link
core content files link command attaching a file to content.
list
core content files list command.
unlink
core content files unlink command.

Enums

ContentFilesCommands

Functions

execute