Module hooks

Module hooks 

core hooks command group: list and validate plugin hook definitions.

Dispatches the HooksCommands subcommands (list, validate) that enumerate hooks across installed plugins and check their definitions.

Copyright (c) systemprompt.io — Business Source License 1.1. See https://systemprompt.io for licensing details.

Modules

list
core hooks list command scanning the hooks directory.
types
Hook-command entry types.
validate
core hooks validate command checking hook commands and plugin-root vars.

Enums

HooksCommands

Functions

execute