core hooks validate command checking hook commands and plugin-root vars.
Copyright (c) systemprompt.io — Business Source License 1.1. See https://systemprompt.io for licensing details.
core hooks validate command checking hook commands and plugin-root vars.
Copyright (c) systemprompt.io — Business Source License 1.1. See https://systemprompt.io for licensing details.