pub struct BatchJobRunOutput {
pub jobs_run: Vec<JobRunOutput>,
pub total: usize,
pub succeeded: usize,
pub failed: usize,
}Fields
jobs_run: Vec<JobRunOutput>total: usizesucceeded: usizefailed: usizeTrait Implementations
Sourceimpl Clone for BatchJobRunOutput
impl Clone for BatchJobRunOutput
Sourcefn clone(&self) -> BatchJobRunOutput
fn clone(&self) -> BatchJobRunOutput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BatchJobRunOutput
impl Debug for BatchJobRunOutput
Sourceimpl<'de> Deserialize<'de> for BatchJobRunOutput
impl<'de> Deserialize<'de> for BatchJobRunOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for BatchJobRunOutput
impl JsonSchema for BatchJobRunOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for BatchJobRunOutput
impl RefUnwindSafe for BatchJobRunOutput
impl Send for BatchJobRunOutput
impl Sync for BatchJobRunOutput
impl Unpin for BatchJobRunOutput
impl UnsafeUnpin for BatchJobRunOutput
impl UnwindSafe for BatchJobRunOutput