pub struct JobRunOutput {
pub job_name: String,
pub status: String,
pub duration_ms: u64,
pub result: JobRunResult,
}Fields
job_name: Stringstatus: Stringduration_ms: u64result: JobRunResultTrait Implementations
Sourceimpl Clone for JobRunOutput
impl Clone for JobRunOutput
Sourcefn clone(&self) -> JobRunOutput
fn clone(&self) -> JobRunOutput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for JobRunOutput
impl Debug for JobRunOutput
Sourceimpl<'de> Deserialize<'de> for JobRunOutput
impl<'de> Deserialize<'de> for JobRunOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for JobRunOutput
impl JsonSchema for JobRunOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for JobRunOutput
impl RefUnwindSafe for JobRunOutput
impl Send for JobRunOutput
impl Sync for JobRunOutput
impl Unpin for JobRunOutput
impl UnwindSafe for JobRunOutput