pub struct JobShowOutput {
pub name: String,
pub description: String,
pub schedule: String,
pub schedule_human: String,
pub enabled: bool,
pub last_run: Option<DateTime<Utc>>,
pub next_run: Option<DateTime<Utc>>,
pub last_status: Option<String>,
pub last_error: Option<String>,
pub run_count: i32,
}Fields
name: Stringdescription: Stringschedule: Stringschedule_human: Stringenabled: boollast_run: Option<DateTime<Utc>>next_run: Option<DateTime<Utc>>last_status: Option<String>last_error: Option<String>run_count: i32Trait Implementations
Sourceimpl Clone for JobShowOutput
impl Clone for JobShowOutput
Sourcefn clone(&self) -> JobShowOutput
fn clone(&self) -> JobShowOutput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for JobShowOutput
impl Debug for JobShowOutput
Sourceimpl<'de> Deserialize<'de> for JobShowOutput
impl<'de> Deserialize<'de> for JobShowOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for JobShowOutput
impl JsonSchema for JobShowOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for JobShowOutput
impl RefUnwindSafe for JobShowOutput
impl Send for JobShowOutput
impl Sync for JobShowOutput
impl Unpin for JobShowOutput
impl UnwindSafe for JobShowOutput