pub struct RequestListOutput {
pub requests: Vec<RequestListRow>,
pub total: u64,
}Fields
requests: Vec<RequestListRow>total: u64Trait Implementations
Sourceimpl Clone for RequestListOutput
impl Clone for RequestListOutput
Sourcefn clone(&self) -> RequestListOutput
fn clone(&self) -> RequestListOutput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RequestListOutput
impl Debug for RequestListOutput
Sourceimpl<'de> Deserialize<'de> for RequestListOutput
impl<'de> Deserialize<'de> for RequestListOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RequestListOutput
impl JsonSchema for RequestListOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RequestListOutput
impl RefUnwindSafe for RequestListOutput
impl Send for RequestListOutput
impl Sync for RequestListOutput
impl Unpin for RequestListOutput
impl UnwindSafe for RequestListOutput