pub struct AuditOutput {
pub request_id: AiRequestId,
pub provider: String,
pub model: String,
pub requested_model: Option<String>,
pub input_tokens: i32,
pub output_tokens: i32,
pub cost_dollars: f64,
pub latency_ms: i64,
pub task_id: Option<TaskId>,
pub trace_id: Option<TraceId>,
pub messages: Vec<MessageRow>,
pub tool_calls: Vec<AuditToolCall>,
}Fields
request_id: AiRequestIdprovider: Stringmodel: Stringrequested_model: Option<String>input_tokens: i32output_tokens: i32cost_dollars: f64latency_ms: i64task_id: Option<TaskId>trace_id: Option<TraceId>messages: Vec<MessageRow>tool_calls: Vec<AuditToolCall>Trait Implementations
Sourceimpl Clone for AuditOutput
impl Clone for AuditOutput
Sourcefn clone(&self) -> AuditOutput
fn clone(&self) -> AuditOutput
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AuditOutput
impl Debug for AuditOutput
Sourceimpl<'de> Deserialize<'de> for AuditOutput
impl<'de> Deserialize<'de> for AuditOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AuditOutput
impl JsonSchema for AuditOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AuditOutput
impl RefUnwindSafe for AuditOutput
impl Send for AuditOutput
impl Sync for AuditOutput
impl Unpin for AuditOutput
impl UnsafeUnpin for AuditOutput
impl UnwindSafe for AuditOutput