pub struct LogDeleteOutput {
pub deleted_count: u64,
pub vacuum_performed: bool,
}Fields
deleted_count: u64vacuum_performed: boolTrait Implementations
Sourceimpl Clone for LogDeleteOutput
impl Clone for LogDeleteOutput
Sourcefn clone(&self) -> LogDeleteOutput
fn clone(&self) -> LogDeleteOutput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LogDeleteOutput
impl Debug for LogDeleteOutput
Sourceimpl<'de> Deserialize<'de> for LogDeleteOutput
impl<'de> Deserialize<'de> for LogDeleteOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for LogDeleteOutput
impl JsonSchema for LogDeleteOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for LogDeleteOutput
impl Serialize for LogDeleteOutput
impl Copy for LogDeleteOutput