pub struct LogEntryRow {
pub id: String,
pub trace_id: String,
pub timestamp: String,
pub level: String,
pub module: String,
pub message: String,
pub metadata: Option<Value>,
}Fields
id: Stringtrace_id: Stringtimestamp: Stringlevel: Stringmodule: Stringmessage: Stringmetadata: Option<Value>Trait Implementations
Sourceimpl Clone for LogEntryRow
impl Clone for LogEntryRow
Sourcefn clone(&self) -> LogEntryRow
fn clone(&self) -> LogEntryRow
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LogEntryRow
impl Debug for LogEntryRow
Sourceimpl<'de> Deserialize<'de> for LogEntryRow
impl<'de> Deserialize<'de> for LogEntryRow
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for LogEntryRow
impl JsonSchema for LogEntryRow
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for LogEntryRow
impl RefUnwindSafe for LogEntryRow
impl Send for LogEntryRow
impl Sync for LogEntryRow
impl Unpin for LogEntryRow
impl UnsafeUnpin for LogEntryRow
impl UnwindSafe for LogEntryRow