pub struct LogFilters {
pub level: Option<String>,
pub module: Option<String>,
pub since: Option<String>,
pub pattern: Option<String>,
pub tail: i64,
}Fields
level: Option<String>module: Option<String>since: Option<String>pattern: Option<String>tail: i64Trait Implementations
Sourceimpl Clone for LogFilters
impl Clone for LogFilters
Sourcefn clone(&self) -> LogFilters
fn clone(&self) -> LogFilters
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LogFilters
impl Debug for LogFilters
Sourceimpl<'de> Deserialize<'de> for LogFilters
impl<'de> Deserialize<'de> for LogFilters
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for LogFilters
impl JsonSchema for LogFilters
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for LogFilters
impl RefUnwindSafe for LogFilters
impl Send for LogFilters
impl Sync for LogFilters
impl Unpin for LogFilters
impl UnsafeUnpin for LogFilters
impl UnwindSafe for LogFilters