pub struct LogViewOutput {
pub logs: Vec<LogEntryRow>,
pub total: u64,
pub filters: LogFilters,
}Fields
logs: Vec<LogEntryRow>total: u64filters: LogFiltersTrait Implementations
Sourceimpl Clone for LogViewOutput
impl Clone for LogViewOutput
Sourcefn clone(&self) -> LogViewOutput
fn clone(&self) -> LogViewOutput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LogViewOutput
impl Debug for LogViewOutput
Sourceimpl<'de> Deserialize<'de> for LogViewOutput
impl<'de> Deserialize<'de> for LogViewOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for LogViewOutput
impl JsonSchema for LogViewOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for LogViewOutput
impl RefUnwindSafe for LogViewOutput
impl Send for LogViewOutput
impl Sync for LogViewOutput
impl Unpin for LogViewOutput
impl UnwindSafe for LogViewOutput