pub struct LogsSummaryOutput {
pub total_logs: i64,
pub by_level: LevelCounts,
pub top_modules: Vec<ModuleCount>,
pub time_range: TimeRange,
pub database_info: DatabaseInfo,
}Fields
total_logs: i64by_level: LevelCountstop_modules: Vec<ModuleCount>time_range: TimeRangedatabase_info: DatabaseInfoTrait Implementations
Sourceimpl Clone for LogsSummaryOutput
impl Clone for LogsSummaryOutput
Sourcefn clone(&self) -> LogsSummaryOutput
fn clone(&self) -> LogsSummaryOutput
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LogsSummaryOutput
impl Debug for LogsSummaryOutput
Sourceimpl<'de> Deserialize<'de> for LogsSummaryOutput
impl<'de> Deserialize<'de> for LogsSummaryOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for LogsSummaryOutput
impl JsonSchema for LogsSummaryOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for LogsSummaryOutput
impl RefUnwindSafe for LogsSummaryOutput
impl Send for LogsSummaryOutput
impl Sync for LogsSummaryOutput
impl Unpin for LogsSummaryOutput
impl UnsafeUnpin for LogsSummaryOutput
impl UnwindSafe for LogsSummaryOutput