pub struct MessageRow {
pub sequence: i32,
pub role: String,
pub content: String,
}Fields
sequence: i32role: Stringcontent: StringTrait Implementations
Sourceimpl Clone for MessageRow
impl Clone for MessageRow
Sourcefn clone(&self) -> MessageRow
fn clone(&self) -> MessageRow
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MessageRow
impl Debug for MessageRow
Sourceimpl<'de> Deserialize<'de> for MessageRow
impl<'de> Deserialize<'de> for MessageRow
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for MessageRow
impl JsonSchema for MessageRow
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for MessageRow
impl RefUnwindSafe for MessageRow
impl Send for MessageRow
impl Sync for MessageRow
impl Unpin for MessageRow
impl UnsafeUnpin for MessageRow
impl UnwindSafe for MessageRow