pub struct ToolsListOutput {
pub executions: Vec<ToolExecutionRow>,
pub total: u64,
}Fields
executions: Vec<ToolExecutionRow>total: u64Trait Implementations
Sourceimpl Clone for ToolsListOutput
impl Clone for ToolsListOutput
Sourcefn clone(&self) -> ToolsListOutput
fn clone(&self) -> ToolsListOutput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ToolsListOutput
impl Debug for ToolsListOutput
Sourceimpl<'de> Deserialize<'de> for ToolsListOutput
impl<'de> Deserialize<'de> for ToolsListOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ToolsListOutput
impl JsonSchema for ToolsListOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ToolsListOutput
impl RefUnwindSafe for ToolsListOutput
impl Send for ToolsListOutput
impl Sync for ToolsListOutput
impl Unpin for ToolsListOutput
impl UnwindSafe for ToolsListOutput