pub struct AiLookupOutput {
pub request_id: String,
pub provider: String,
pub model: String,
pub input_tokens: i32,
pub output_tokens: i32,
pub cost_dollars: f64,
pub latency_ms: i64,
pub messages: Vec<MessageRow>,
pub linked_mcp_calls: Vec<ToolCallRow>,
}Fields
request_id: Stringprovider: Stringmodel: Stringinput_tokens: i32output_tokens: i32cost_dollars: f64latency_ms: i64messages: Vec<MessageRow>linked_mcp_calls: Vec<ToolCallRow>Trait Implementations
Sourceimpl Clone for AiLookupOutput
impl Clone for AiLookupOutput
Sourcefn clone(&self) -> AiLookupOutput
fn clone(&self) -> AiLookupOutput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AiLookupOutput
impl Debug for AiLookupOutput
Sourceimpl<'de> Deserialize<'de> for AiLookupOutput
impl<'de> Deserialize<'de> for AiLookupOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AiLookupOutput
impl JsonSchema for AiLookupOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AiLookupOutput
impl RefUnwindSafe for AiLookupOutput
impl Send for AiLookupOutput
impl Sync for AiLookupOutput
impl Unpin for AiLookupOutput
impl UnsafeUnpin for AiLookupOutput
impl UnwindSafe for AiLookupOutput