pub struct AiRequestRow {
pub request_id: String,
pub model: String,
pub max_tokens: Option<i32>,
pub tokens: String,
pub cost: String,
pub latency_ms: Option<i64>,
}Fields
request_id: Stringmodel: Stringmax_tokens: Option<i32>tokens: Stringcost: Stringlatency_ms: Option<i64>Trait Implementations
Sourceimpl Clone for AiRequestRow
impl Clone for AiRequestRow
Sourcefn clone(&self) -> AiRequestRow
fn clone(&self) -> AiRequestRow
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AiRequestRow
impl Debug for AiRequestRow
Sourceimpl<'de> Deserialize<'de> for AiRequestRow
impl<'de> Deserialize<'de> for AiRequestRow
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AiRequestRow
impl JsonSchema for AiRequestRow
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AiRequestRow
impl RefUnwindSafe for AiRequestRow
impl Send for AiRequestRow
impl Sync for AiRequestRow
impl Unpin for AiRequestRow
impl UnwindSafe for AiRequestRow