pub struct AiSummaryRow {
pub request_count: i64,
pub total_tokens: i64,
pub input_tokens: i64,
pub output_tokens: i64,
pub cost_dollars: f64,
pub total_latency_ms: i64,
}Fields
request_count: i64total_tokens: i64input_tokens: i64output_tokens: i64cost_dollars: f64total_latency_ms: i64Trait Implementations
Sourceimpl Clone for AiSummaryRow
impl Clone for AiSummaryRow
Sourcefn clone(&self) -> AiSummaryRow
fn clone(&self) -> AiSummaryRow
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AiSummaryRow
impl Debug for AiSummaryRow
Sourceimpl<'de> Deserialize<'de> for AiSummaryRow
impl<'de> Deserialize<'de> for AiSummaryRow
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AiSummaryRow
impl JsonSchema for AiSummaryRow
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for AiSummaryRow
impl Serialize for AiSummaryRow
impl Copy for AiSummaryRow