pub struct AiTraceOutput {
pub task_id: String,
pub task_info: TaskInfoRow,
pub user_input: Option<String>,
pub execution_steps: Vec<StepRow>,
pub ai_requests: Vec<AiRequestRow>,
pub mcp_executions: Vec<ToolCallRow>,
pub artifacts: Vec<ArtifactRow>,
pub agent_response: Option<String>,
}Fields
task_id: Stringtask_info: TaskInfoRowuser_input: Option<String>execution_steps: Vec<StepRow>ai_requests: Vec<AiRequestRow>mcp_executions: Vec<ToolCallRow>artifacts: Vec<ArtifactRow>agent_response: Option<String>Trait Implementations
Sourceimpl Clone for AiTraceOutput
impl Clone for AiTraceOutput
Sourcefn clone(&self) -> AiTraceOutput
fn clone(&self) -> AiTraceOutput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AiTraceOutput
impl Debug for AiTraceOutput
Sourceimpl<'de> Deserialize<'de> for AiTraceOutput
impl<'de> Deserialize<'de> for AiTraceOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AiTraceOutput
impl JsonSchema for AiTraceOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AiTraceOutput
impl RefUnwindSafe for AiTraceOutput
impl Send for AiTraceOutput
impl Sync for AiTraceOutput
impl Unpin for AiTraceOutput
impl UnsafeUnpin for AiTraceOutput
impl UnwindSafe for AiTraceOutput