pub struct StepSummaryRow {
pub total: i64,
pub completed: i64,
pub failed: i64,
pub pending: i64,
}Fields
total: i64completed: i64failed: i64pending: i64Trait Implementations
Sourceimpl Clone for StepSummaryRow
impl Clone for StepSummaryRow
Sourcefn clone(&self) -> StepSummaryRow
fn clone(&self) -> StepSummaryRow
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for StepSummaryRow
Sourceimpl Debug for StepSummaryRow
impl Debug for StepSummaryRow
Sourceimpl<'de> Deserialize<'de> for StepSummaryRow
impl<'de> Deserialize<'de> for StepSummaryRow
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for StepSummaryRow
impl JsonSchema for StepSummaryRow
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for StepSummaryRow
impl RefUnwindSafe for StepSummaryRow
impl Send for StepSummaryRow
impl Sync for StepSummaryRow
impl Unpin for StepSummaryRow
impl UnsafeUnpin for StepSummaryRow
impl UnwindSafe for StepSummaryRow