pub struct TaskInfoRow {
pub task_id: String,
pub agent_name: Option<String>,
pub status: String,
pub started_at: Option<String>,
pub duration_ms: Option<i64>,
}Fields
task_id: Stringagent_name: Option<String>status: Stringstarted_at: Option<String>duration_ms: Option<i64>Trait Implementations
Sourceimpl Clone for TaskInfoRow
impl Clone for TaskInfoRow
Sourcefn clone(&self) -> TaskInfoRow
fn clone(&self) -> TaskInfoRow
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TaskInfoRow
impl Debug for TaskInfoRow
Sourceimpl<'de> Deserialize<'de> for TaskInfoRow
impl<'de> Deserialize<'de> for TaskInfoRow
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for TaskInfoRow
impl JsonSchema for TaskInfoRow
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for TaskInfoRow
impl RefUnwindSafe for TaskInfoRow
impl Send for TaskInfoRow
impl Sync for TaskInfoRow
impl Unpin for TaskInfoRow
impl UnsafeUnpin for TaskInfoRow
impl UnwindSafe for TaskInfoRow