pub struct TraceEventRow {
pub timestamp: String,
pub delta_ms: i64,
pub event_type: String,
pub details: String,
pub latency_ms: Option<i64>,
}Fields
timestamp: Stringdelta_ms: i64event_type: Stringdetails: Stringlatency_ms: Option<i64>Trait Implementations
Sourceimpl Clone for TraceEventRow
impl Clone for TraceEventRow
Sourcefn clone(&self) -> TraceEventRow
fn clone(&self) -> TraceEventRow
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TraceEventRow
impl Debug for TraceEventRow
Sourceimpl<'de> Deserialize<'de> for TraceEventRow
impl<'de> Deserialize<'de> for TraceEventRow
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for TraceEventRow
impl JsonSchema for TraceEventRow
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for TraceEventRow
impl RefUnwindSafe for TraceEventRow
impl Send for TraceEventRow
impl Sync for TraceEventRow
impl Unpin for TraceEventRow
impl UnsafeUnpin for TraceEventRow
impl UnwindSafe for TraceEventRow