pub struct TraceListOutput {
pub traces: Vec<TraceListRow>,
pub total: u64,
}Fields
traces: Vec<TraceListRow>total: u64Trait Implementations
Sourceimpl Clone for TraceListOutput
impl Clone for TraceListOutput
Sourcefn clone(&self) -> TraceListOutput
fn clone(&self) -> TraceListOutput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TraceListOutput
impl Debug for TraceListOutput
Sourceimpl<'de> Deserialize<'de> for TraceListOutput
impl<'de> Deserialize<'de> for TraceListOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for TraceListOutput
impl JsonSchema for TraceListOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for TraceListOutput
impl RefUnwindSafe for TraceListOutput
impl Send for TraceListOutput
impl Sync for TraceListOutput
impl Unpin for TraceListOutput
impl UnwindSafe for TraceListOutput