pub struct TraceListRow {
pub trace_id: String,
pub timestamp: String,
pub agent: Option<String>,
pub status: String,
pub duration_ms: Option<i64>,
pub ai_requests: i64,
pub mcp_calls: i64,
}Fields
trace_id: Stringtimestamp: Stringagent: Option<String>status: Stringduration_ms: Option<i64>ai_requests: i64mcp_calls: i64Trait Implementations
Sourceimpl Clone for TraceListRow
impl Clone for TraceListRow
Sourcefn clone(&self) -> TraceListRow
fn clone(&self) -> TraceListRow
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TraceListRow
impl Debug for TraceListRow
Sourceimpl<'de> Deserialize<'de> for TraceListRow
impl<'de> Deserialize<'de> for TraceListRow
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for TraceListRow
impl JsonSchema for TraceListRow
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for TraceListRow
impl RefUnwindSafe for TraceListRow
impl Send for TraceListRow
impl Sync for TraceListRow
impl Unpin for TraceListRow
impl UnsafeUnpin for TraceListRow
impl UnwindSafe for TraceListRow