pub struct TraceViewOutput {
pub trace_id: String,
pub events: Vec<TraceEventRow>,
pub ai_summary: AiSummaryRow,
pub mcp_summary: McpSummaryRow,
pub step_summary: StepSummaryRow,
pub task_id: Option<String>,
pub duration_ms: Option<i64>,
pub status: String,
}Fields
trace_id: Stringevents: Vec<TraceEventRow>ai_summary: AiSummaryRowmcp_summary: McpSummaryRowstep_summary: StepSummaryRowtask_id: Option<String>duration_ms: Option<i64>status: StringTrait Implementations
Sourceimpl Clone for TraceViewOutput
impl Clone for TraceViewOutput
Sourcefn clone(&self) -> TraceViewOutput
fn clone(&self) -> TraceViewOutput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TraceViewOutput
impl Debug for TraceViewOutput
Sourceimpl<'de> Deserialize<'de> for TraceViewOutput
impl<'de> Deserialize<'de> for TraceViewOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for TraceViewOutput
impl JsonSchema for TraceViewOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for TraceViewOutput
impl RefUnwindSafe for TraceViewOutput
impl Send for TraceViewOutput
impl Sync for TraceViewOutput
impl Unpin for TraceViewOutput
impl UnwindSafe for TraceViewOutput