pub struct ServiceStatusOutput {
pub services: Vec<ServiceStatusRow>,
pub summary: StatusSummary,
}Fields
services: Vec<ServiceStatusRow>summary: StatusSummaryTrait Implementations
Sourceimpl Clone for ServiceStatusOutput
impl Clone for ServiceStatusOutput
Sourcefn clone(&self) -> ServiceStatusOutput
fn clone(&self) -> ServiceStatusOutput
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ServiceStatusOutput
impl Debug for ServiceStatusOutput
Sourceimpl<'de> Deserialize<'de> for ServiceStatusOutput
impl<'de> Deserialize<'de> for ServiceStatusOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ServiceStatusOutput
impl JsonSchema for ServiceStatusOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ServiceStatusOutput
impl RefUnwindSafe for ServiceStatusOutput
impl Send for ServiceStatusOutput
impl Sync for ServiceStatusOutput
impl Unpin for ServiceStatusOutput
impl UnsafeUnpin for ServiceStatusOutput
impl UnwindSafe for ServiceStatusOutput