pub struct StatusSummary {
pub total: usize,
pub running: usize,
pub stopped: usize,
}Fields
total: usizerunning: usizestopped: usizeTrait Implementations
Sourceimpl Clone for StatusSummary
impl Clone for StatusSummary
Sourcefn clone(&self) -> StatusSummary
fn clone(&self) -> StatusSummary
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for StatusSummary
Sourceimpl Debug for StatusSummary
impl Debug for StatusSummary
Sourceimpl<'de> Deserialize<'de> for StatusSummary
impl<'de> Deserialize<'de> for StatusSummary
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for StatusSummary
impl JsonSchema for StatusSummary
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for StatusSummary
impl RefUnwindSafe for StatusSummary
impl Send for StatusSummary
impl Sync for StatusSummary
impl Unpin for StatusSummary
impl UnsafeUnpin for StatusSummary
impl UnwindSafe for StatusSummary