pub struct McpLogsOutput {
pub service: Option<String>,
pub source: String,
pub logs: Vec<String>,
pub log_files: Vec<String>,
}Fields
service: Option<String>source: Stringlogs: Vec<String>log_files: Vec<String>Trait Implementations
Sourceimpl Clone for McpLogsOutput
impl Clone for McpLogsOutput
Sourcefn clone(&self) -> McpLogsOutput
fn clone(&self) -> McpLogsOutput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for McpLogsOutput
impl Debug for McpLogsOutput
Sourceimpl<'de> Deserialize<'de> for McpLogsOutput
impl<'de> Deserialize<'de> for McpLogsOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for McpLogsOutput
impl JsonSchema for McpLogsOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for McpLogsOutput
impl RefUnwindSafe for McpLogsOutput
impl Send for McpLogsOutput
impl Sync for McpLogsOutput
impl Unpin for McpLogsOutput
impl UnwindSafe for McpLogsOutput