pub struct McpPackagesOutput {
pub packages: Vec<String>,
pub raw_packages: Option<String>,
}Fields
packages: Vec<String>raw_packages: Option<String>Trait Implementations
Sourceimpl Clone for McpPackagesOutput
impl Clone for McpPackagesOutput
Sourcefn clone(&self) -> McpPackagesOutput
fn clone(&self) -> McpPackagesOutput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for McpPackagesOutput
impl Debug for McpPackagesOutput
Sourceimpl<'de> Deserialize<'de> for McpPackagesOutput
impl<'de> Deserialize<'de> for McpPackagesOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for McpPackagesOutput
impl JsonSchema for McpPackagesOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for McpPackagesOutput
impl RefUnwindSafe for McpPackagesOutput
impl Send for McpPackagesOutput
impl Sync for McpPackagesOutput
impl Unpin for McpPackagesOutput
impl UnsafeUnpin for McpPackagesOutput
impl UnwindSafe for McpPackagesOutput