pub struct McpServerInfo {
pub name: String,
pub version: String,
pub protocol_version: String,
}Fields
name: Stringversion: Stringprotocol_version: StringTrait Implementations
Sourceimpl Clone for McpServerInfo
impl Clone for McpServerInfo
Sourcefn clone(&self) -> McpServerInfo
fn clone(&self) -> McpServerInfo
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for McpServerInfo
impl Debug for McpServerInfo
Sourceimpl<'de> Deserialize<'de> for McpServerInfo
impl<'de> Deserialize<'de> for McpServerInfo
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for McpServerInfo
impl JsonSchema for McpServerInfo
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for McpServerInfo
impl RefUnwindSafe for McpServerInfo
impl Send for McpServerInfo
impl Sync for McpServerInfo
impl Unpin for McpServerInfo
impl UnsafeUnpin for McpServerInfo
impl UnwindSafe for McpServerInfo