pub struct McpServerSummary {
pub name: String,
pub port: u16,
pub enabled: bool,
pub status: String,
pub debug_binary: Option<String>,
pub debug_created_at: Option<String>,
pub release_binary: Option<String>,
pub release_created_at: Option<String>,
}Fields
name: Stringport: u16enabled: boolstatus: Stringdebug_binary: Option<String>debug_created_at: Option<String>release_binary: Option<String>release_created_at: Option<String>Trait Implementations
Sourceimpl Clone for McpServerSummary
impl Clone for McpServerSummary
Sourcefn clone(&self) -> McpServerSummary
fn clone(&self) -> McpServerSummary
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for McpServerSummary
impl Debug for McpServerSummary
Sourceimpl<'de> Deserialize<'de> for McpServerSummary
impl<'de> Deserialize<'de> for McpServerSummary
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for McpServerSummary
impl JsonSchema for McpServerSummary
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for McpServerSummary
impl RefUnwindSafe for McpServerSummary
impl Send for McpServerSummary
impl Sync for McpServerSummary
impl Unpin for McpServerSummary
impl UnsafeUnpin for McpServerSummary
impl UnwindSafe for McpServerSummary