pub struct McpStatusEntry {
pub name: String,
pub port: u16,
pub enabled: bool,
pub running: bool,
pub pid: Option<u32>,
pub binary: String,
pub release_binary: Option<String>,
pub debug_binary: Option<String>,
}Fields
name: Stringport: u16enabled: boolrunning: boolpid: Option<u32>binary: Stringrelease_binary: Option<String>debug_binary: Option<String>Trait Implementations
Sourceimpl Clone for McpStatusEntry
impl Clone for McpStatusEntry
Sourcefn clone(&self) -> McpStatusEntry
fn clone(&self) -> McpStatusEntry
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for McpStatusEntry
impl Debug for McpStatusEntry
Sourceimpl<'de> Deserialize<'de> for McpStatusEntry
impl<'de> Deserialize<'de> for McpStatusEntry
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for McpStatusEntry
impl JsonSchema for McpStatusEntry
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for McpStatusEntry
impl RefUnwindSafe for McpStatusEntry
impl Send for McpStatusEntry
impl Sync for McpStatusEntry
impl Unpin for McpStatusEntry
impl UnsafeUnpin for McpStatusEntry
impl UnwindSafe for McpStatusEntry