pub struct McpStatusOutput {
pub servers: Vec<McpStatusEntry>,
pub summary: McpStatusSummary,
}Fields
servers: Vec<McpStatusEntry>summary: McpStatusSummaryTrait Implementations
Sourceimpl Clone for McpStatusOutput
impl Clone for McpStatusOutput
Sourcefn clone(&self) -> McpStatusOutput
fn clone(&self) -> McpStatusOutput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for McpStatusOutput
impl Debug for McpStatusOutput
Sourceimpl<'de> Deserialize<'de> for McpStatusOutput
impl<'de> Deserialize<'de> for McpStatusOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for McpStatusOutput
impl JsonSchema for McpStatusOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for McpStatusOutput
impl RefUnwindSafe for McpStatusOutput
impl Send for McpStatusOutput
impl Sync for McpStatusOutput
impl Unpin for McpStatusOutput
impl UnsafeUnpin for McpStatusOutput
impl UnwindSafe for McpStatusOutput