pub struct McpStatusSummary {
pub total: usize,
pub enabled: usize,
pub running: usize,
}Fields
total: usizeenabled: usizerunning: usizeTrait Implementations
Sourceimpl Clone for McpStatusSummary
impl Clone for McpStatusSummary
Sourcefn clone(&self) -> McpStatusSummary
fn clone(&self) -> McpStatusSummary
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for McpStatusSummary
impl Debug for McpStatusSummary
Sourceimpl<'de> Deserialize<'de> for McpStatusSummary
impl<'de> Deserialize<'de> for McpStatusSummary
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for McpStatusSummary
impl JsonSchema for McpStatusSummary
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for McpStatusSummary
impl Serialize for McpStatusSummary
impl Copy for McpStatusSummary