pub struct McpToolEntry {
pub name: String,
pub server: String,
pub description: Option<String>,
pub parameters_count: usize,
pub input_schema: Option<Value>,
pub output_schema: Option<Value>,
}Fields
name: Stringserver: Stringdescription: Option<String>parameters_count: usizeinput_schema: Option<Value>output_schema: Option<Value>Trait Implementations
Sourceimpl Clone for McpToolEntry
impl Clone for McpToolEntry
Sourcefn clone(&self) -> McpToolEntry
fn clone(&self) -> McpToolEntry
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for McpToolEntry
impl Debug for McpToolEntry
Sourceimpl<'de> Deserialize<'de> for McpToolEntry
impl<'de> Deserialize<'de> for McpToolEntry
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for McpToolEntry
impl JsonSchema for McpToolEntry
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for McpToolEntry
impl RefUnwindSafe for McpToolEntry
impl Send for McpToolEntry
impl Sync for McpToolEntry
impl Unpin for McpToolEntry
impl UnsafeUnpin for McpToolEntry
impl UnwindSafe for McpToolEntry