pub struct McpToolsOutput {
pub tools: Vec<McpToolEntry>,
pub summary: McpToolsSummary,
}Fields
tools: Vec<McpToolEntry>summary: McpToolsSummaryTrait Implementations
Sourceimpl Clone for McpToolsOutput
impl Clone for McpToolsOutput
Sourcefn clone(&self) -> McpToolsOutput
fn clone(&self) -> McpToolsOutput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for McpToolsOutput
impl Debug for McpToolsOutput
Sourceimpl<'de> Deserialize<'de> for McpToolsOutput
impl<'de> Deserialize<'de> for McpToolsOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for McpToolsOutput
impl JsonSchema for McpToolsOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for McpToolsOutput
impl RefUnwindSafe for McpToolsOutput
impl Send for McpToolsOutput
impl Sync for McpToolsOutput
impl Unpin for McpToolsOutput
impl UnsafeUnpin for McpToolsOutput
impl UnwindSafe for McpToolsOutput