pub struct McpToolsSummary {
pub total_tools: usize,
pub servers_queried: usize,
}Fields
total_tools: usizeservers_queried: usizeTrait Implementations
Sourceimpl Clone for McpToolsSummary
impl Clone for McpToolsSummary
Sourcefn clone(&self) -> McpToolsSummary
fn clone(&self) -> McpToolsSummary
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for McpToolsSummary
impl Debug for McpToolsSummary
Sourceimpl<'de> Deserialize<'de> for McpToolsSummary
impl<'de> Deserialize<'de> for McpToolsSummary
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for McpToolsSummary
impl JsonSchema for McpToolsSummary
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for McpToolsSummary
impl Serialize for McpToolsSummary
impl Copy for McpToolsSummary