pub struct McpValidateOutput {
pub server: String,
pub valid: bool,
pub health_status: String,
pub validation_type: String,
pub tools_count: usize,
pub latency_ms: u32,
pub server_info: Option<McpServerInfo>,
pub issues: Vec<String>,
pub message: String,
}Fields
server: Stringvalid: boolhealth_status: Stringvalidation_type: Stringtools_count: usizelatency_ms: u32server_info: Option<McpServerInfo>issues: Vec<String>message: StringTrait Implementations
Sourceimpl Clone for McpValidateOutput
impl Clone for McpValidateOutput
Sourcefn clone(&self) -> McpValidateOutput
fn clone(&self) -> McpValidateOutput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for McpValidateOutput
impl Debug for McpValidateOutput
Sourceimpl<'de> Deserialize<'de> for McpValidateOutput
impl<'de> Deserialize<'de> for McpValidateOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for McpValidateOutput
impl JsonSchema for McpValidateOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for McpValidateOutput
impl RefUnwindSafe for McpValidateOutput
impl Send for McpValidateOutput
impl Sync for McpValidateOutput
impl Unpin for McpValidateOutput
impl UnsafeUnpin for McpValidateOutput
impl UnwindSafe for McpValidateOutput