pub struct McpValidateSummary {
pub total: usize,
pub valid: usize,
pub invalid: usize,
pub healthy: usize,
pub unhealthy: usize,
}Fields
total: usizevalid: usizeinvalid: usizehealthy: usizeunhealthy: usizeTrait Implementations
Sourceimpl Clone for McpValidateSummary
impl Clone for McpValidateSummary
Sourcefn clone(&self) -> McpValidateSummary
fn clone(&self) -> McpValidateSummary
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for McpValidateSummary
impl Debug for McpValidateSummary
Sourceimpl<'de> Deserialize<'de> for McpValidateSummary
impl<'de> Deserialize<'de> for McpValidateSummary
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for McpValidateSummary
impl JsonSchema for McpValidateSummary
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for McpValidateSummary
impl Serialize for McpValidateSummary
impl Copy for McpValidateSummary