pub struct CapabilitiesSummaryOutput {
pub jobs: usize,
pub templates: usize,
pub schemas: usize,
pub tools: usize,
pub roles: usize,
pub llm_providers: usize,
pub extension_count: usize,
}Fields
jobs: usizetemplates: usizeschemas: usizetools: usizeroles: usizellm_providers: usizeextension_count: usizeTrait Implementations
Sourceimpl Clone for CapabilitiesSummaryOutput
impl Clone for CapabilitiesSummaryOutput
Sourcefn clone(&self) -> CapabilitiesSummaryOutput
fn clone(&self) -> CapabilitiesSummaryOutput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CapabilitiesSummaryOutput
impl Debug for CapabilitiesSummaryOutput
Sourceimpl<'de> Deserialize<'de> for CapabilitiesSummaryOutput
impl<'de> Deserialize<'de> for CapabilitiesSummaryOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CapabilitiesSummaryOutput
impl JsonSchema for CapabilitiesSummaryOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl Copy for CapabilitiesSummaryOutput