pub struct CliExtensionInfo {
pub name: String,
pub binary: String,
pub description: String,
pub commands: Vec<CliCommandInfo>,
pub enabled: bool,
}Fields
name: Stringbinary: Stringdescription: Stringcommands: Vec<CliCommandInfo>enabled: boolTrait Implementations
Sourceimpl Clone for CliExtensionInfo
impl Clone for CliExtensionInfo
Sourcefn clone(&self) -> CliExtensionInfo
fn clone(&self) -> CliExtensionInfo
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CliExtensionInfo
impl Debug for CliExtensionInfo
Sourceimpl<'de> Deserialize<'de> for CliExtensionInfo
impl<'de> Deserialize<'de> for CliExtensionInfo
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CliExtensionInfo
impl JsonSchema for CliExtensionInfo
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for CliExtensionInfo
impl RefUnwindSafe for CliExtensionInfo
impl Send for CliExtensionInfo
impl Sync for CliExtensionInfo
impl Unpin for CliExtensionInfo
impl UnsafeUnpin for CliExtensionInfo
impl UnwindSafe for CliExtensionInfo