pub struct ExtensionConfigSummary {
pub extension_id: String,
pub config_prefix: Option<String>,
pub has_config: bool,
}Fields
extension_id: Stringconfig_prefix: Option<String>has_config: boolTrait Implementations
Sourceimpl Clone for ExtensionConfigSummary
impl Clone for ExtensionConfigSummary
Sourcefn clone(&self) -> ExtensionConfigSummary
fn clone(&self) -> ExtensionConfigSummary
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExtensionConfigSummary
impl Debug for ExtensionConfigSummary
Sourceimpl<'de> Deserialize<'de> for ExtensionConfigSummary
impl<'de> Deserialize<'de> for ExtensionConfigSummary
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ExtensionConfigSummary
impl JsonSchema for ExtensionConfigSummary
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ExtensionConfigSummary
impl RefUnwindSafe for ExtensionConfigSummary
impl Send for ExtensionConfigSummary
impl Sync for ExtensionConfigSummary
impl Unpin for ExtensionConfigSummary
impl UnwindSafe for ExtensionConfigSummary