pub struct ExtensionDetailOutput {Show 15 fields
pub id: String,
pub name: String,
pub version: String,
pub priority: u32,
pub source: ExtensionSource,
pub dependencies: Vec<String>,
pub config_prefix: Option<String>,
pub jobs: Vec<JobInfo>,
pub templates: Vec<TemplateInfo>,
pub schemas: Vec<SchemaInfo>,
pub routes: Vec<RouteInfo>,
pub tools: Vec<ToolInfo>,
pub roles: Vec<RoleInfo>,
pub llm_providers: Vec<LlmProviderInfo>,
pub storage_paths: Vec<String>,
}Fields
id: Stringname: Stringversion: Stringpriority: u32source: ExtensionSourcedependencies: Vec<String>config_prefix: Option<String>jobs: Vec<JobInfo>templates: Vec<TemplateInfo>schemas: Vec<SchemaInfo>routes: Vec<RouteInfo>tools: Vec<ToolInfo>roles: Vec<RoleInfo>llm_providers: Vec<LlmProviderInfo>storage_paths: Vec<String>Trait Implementations
Sourceimpl Clone for ExtensionDetailOutput
impl Clone for ExtensionDetailOutput
Sourcefn clone(&self) -> ExtensionDetailOutput
fn clone(&self) -> ExtensionDetailOutput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExtensionDetailOutput
impl Debug for ExtensionDetailOutput
Sourceimpl<'de> Deserialize<'de> for ExtensionDetailOutput
impl<'de> Deserialize<'de> for ExtensionDetailOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ExtensionDetailOutput
impl JsonSchema for ExtensionDetailOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ExtensionDetailOutput
impl RefUnwindSafe for ExtensionDetailOutput
impl Send for ExtensionDetailOutput
impl Sync for ExtensionDetailOutput
impl Unpin for ExtensionDetailOutput
impl UnsafeUnpin for ExtensionDetailOutput
impl UnwindSafe for ExtensionDetailOutput