pub struct ExtensionValidationOutput {
pub valid: bool,
pub extension_count: usize,
pub errors: Vec<ValidationError>,
pub warnings: Vec<ValidationWarning>,
}Fields
valid: boolextension_count: usizeerrors: Vec<ValidationError>warnings: Vec<ValidationWarning>Trait Implementations
Sourceimpl Clone for ExtensionValidationOutput
impl Clone for ExtensionValidationOutput
Sourcefn clone(&self) -> ExtensionValidationOutput
fn clone(&self) -> ExtensionValidationOutput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExtensionValidationOutput
impl Debug for ExtensionValidationOutput
Sourceimpl<'de> Deserialize<'de> for ExtensionValidationOutput
impl<'de> Deserialize<'de> for ExtensionValidationOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ExtensionValidationOutput
impl JsonSchema for ExtensionValidationOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ExtensionValidationOutput
impl RefUnwindSafe for ExtensionValidationOutput
impl Send for ExtensionValidationOutput
impl Sync for ExtensionValidationOutput
impl Unpin for ExtensionValidationOutput
impl UnsafeUnpin for ExtensionValidationOutput
impl UnwindSafe for ExtensionValidationOutput