pub struct JobWithExtension {
pub extension_id: String,
pub extension_name: String,
pub job_name: String,
pub schedule: String,
pub enabled: bool,
}Fields
extension_id: Stringextension_name: Stringjob_name: Stringschedule: Stringenabled: boolTrait Implementations
Sourceimpl Clone for JobWithExtension
impl Clone for JobWithExtension
Sourcefn clone(&self) -> JobWithExtension
fn clone(&self) -> JobWithExtension
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for JobWithExtension
impl Debug for JobWithExtension
Sourceimpl<'de> Deserialize<'de> for JobWithExtension
impl<'de> Deserialize<'de> for JobWithExtension
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for JobWithExtension
impl JsonSchema for JobWithExtension
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for JobWithExtension
impl RefUnwindSafe for JobWithExtension
impl Send for JobWithExtension
impl Sync for JobWithExtension
impl Unpin for JobWithExtension
impl UnwindSafe for JobWithExtension