pub struct LlmProviderWithExtension {
pub extension_id: String,
pub extension_name: String,
pub provider_name: String,
}Fields
extension_id: Stringextension_name: Stringprovider_name: StringTrait Implementations
Sourceimpl Clone for LlmProviderWithExtension
impl Clone for LlmProviderWithExtension
Sourcefn clone(&self) -> LlmProviderWithExtension
fn clone(&self) -> LlmProviderWithExtension
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LlmProviderWithExtension
impl Debug for LlmProviderWithExtension
Sourceimpl<'de> Deserialize<'de> for LlmProviderWithExtension
impl<'de> Deserialize<'de> for LlmProviderWithExtension
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for LlmProviderWithExtension
impl JsonSchema for LlmProviderWithExtension
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for LlmProviderWithExtension
impl RefUnwindSafe for LlmProviderWithExtension
impl Send for LlmProviderWithExtension
impl Sync for LlmProviderWithExtension
impl Unpin for LlmProviderWithExtension
impl UnwindSafe for LlmProviderWithExtension