pub struct RoleInfo {
pub name: String,
pub display_name: String,
pub description: String,
pub permissions: Vec<String>,
}Fields
name: Stringdisplay_name: Stringdescription: Stringpermissions: Vec<String>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for RoleInfo
impl<'de> Deserialize<'de> for RoleInfo
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RoleInfo
impl JsonSchema for RoleInfo
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RoleInfo
impl RefUnwindSafe for RoleInfo
impl Send for RoleInfo
impl Sync for RoleInfo
impl Unpin for RoleInfo
impl UnwindSafe for RoleInfo