pub struct RoleWithExtension {
pub extension_id: String,
pub extension_name: String,
pub role_name: String,
pub display_name: String,
pub description: String,
pub permissions: Vec<String>,
}Fields
extension_id: Stringextension_name: Stringrole_name: Stringdisplay_name: Stringdescription: Stringpermissions: Vec<String>Trait Implementations
Sourceimpl Clone for RoleWithExtension
impl Clone for RoleWithExtension
Sourcefn clone(&self) -> RoleWithExtension
fn clone(&self) -> RoleWithExtension
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RoleWithExtension
impl Debug for RoleWithExtension
Sourceimpl<'de> Deserialize<'de> for RoleWithExtension
impl<'de> Deserialize<'de> for RoleWithExtension
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RoleWithExtension
impl JsonSchema for RoleWithExtension
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RoleWithExtension
impl RefUnwindSafe for RoleWithExtension
impl Send for RoleWithExtension
impl Sync for RoleWithExtension
impl Unpin for RoleWithExtension
impl UnwindSafe for RoleWithExtension