pub struct RouteWithExtension {
pub extension_id: String,
pub extension_name: String,
pub base_path: String,
pub requires_auth: bool,
}Fields
extension_id: Stringextension_name: Stringbase_path: Stringrequires_auth: boolTrait Implementations
Sourceimpl Clone for RouteWithExtension
impl Clone for RouteWithExtension
Sourcefn clone(&self) -> RouteWithExtension
fn clone(&self) -> RouteWithExtension
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RouteWithExtension
impl Debug for RouteWithExtension
Sourceimpl<'de> Deserialize<'de> for RouteWithExtension
impl<'de> Deserialize<'de> for RouteWithExtension
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RouteWithExtension
impl JsonSchema for RouteWithExtension
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RouteWithExtension
impl RefUnwindSafe for RouteWithExtension
impl Send for RouteWithExtension
impl Sync for RouteWithExtension
impl Unpin for RouteWithExtension
impl UnsafeUnpin for RouteWithExtension
impl UnwindSafe for RouteWithExtension