pub struct SchemaInfo {
pub table: String,
pub source: String,
pub required_columns: Vec<String>,
}Fields
table: Stringsource: Stringrequired_columns: Vec<String>Trait Implementations
Sourceimpl Clone for SchemaInfo
impl Clone for SchemaInfo
Sourcefn clone(&self) -> SchemaInfo
fn clone(&self) -> SchemaInfo
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SchemaInfo
impl Debug for SchemaInfo
Sourceimpl<'de> Deserialize<'de> for SchemaInfo
impl<'de> Deserialize<'de> for SchemaInfo
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SchemaInfo
impl JsonSchema for SchemaInfo
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SchemaInfo
impl RefUnwindSafe for SchemaInfo
impl Send for SchemaInfo
impl Sync for SchemaInfo
impl Unpin for SchemaInfo
impl UnwindSafe for SchemaInfo