pub struct ValidationWarning {
pub extension_id: Option<String>,
pub warning_type: String,
pub message: String,
}Fields
extension_id: Option<String>warning_type: Stringmessage: StringTrait Implementations
Sourceimpl Clone for ValidationWarning
impl Clone for ValidationWarning
Sourcefn clone(&self) -> ValidationWarning
fn clone(&self) -> ValidationWarning
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ValidationWarning
impl Debug for ValidationWarning
Sourceimpl<'de> Deserialize<'de> for ValidationWarning
impl<'de> Deserialize<'de> for ValidationWarning
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ValidationWarning
impl JsonSchema for ValidationWarning
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ValidationWarning
impl RefUnwindSafe for ValidationWarning
impl Send for ValidationWarning
impl Sync for ValidationWarning
impl Unpin for ValidationWarning
impl UnsafeUnpin for ValidationWarning
impl UnwindSafe for ValidationWarning