Read-only inspection of web assets (CSS, fonts, images, favicons).
Dispatches the web assets subcommands (AssetsCommands) to list the
asset inventory or show details for a single asset.
Read-only inspection of web assets (CSS, fonts, images, favicons).
Dispatches the web assets subcommands (AssetsCommands) to list the
asset inventory or show details for a single asset.