Module sitemap

Module sitemap 

Sitemap inspection and generation for the web content config.

Dispatches the web sitemap subcommands (SitemapCommands) to show the configured routes or generate a sitemap.xml.

Copyright (c) systemprompt.io — Business Source License 1.1. See https://systemprompt.io for licensing details.

Modules

generate
web sitemap generate command collecting URLs into sitemap.xml.
show
web sitemap show command with XML preview.

Enums

SitemapCommands

Functions

execute