Module templates

Module templates 

Management of HTML templates and their content-type bindings.

Dispatches the web templates subcommands (TemplatesCommands) to list, show, create, edit, and delete templates in the web templates config.

Copyright (c) systemprompt.io — Business Source License 1.1. See https://systemprompt.io for licensing details.

Modules

create
web templates create command registering a template in templates.yaml.
delete
web templates delete command.
edit
web templates edit command applying content-type binding edits.
list
web templates list command.
selection
Interactive template selection.
show
web templates show command listing template variables.

Enums

TemplatesCommands

Functions

execute