pub struct AssetDetailOutput {
pub path: String,
pub absolute_path: String,
pub asset_type: AssetType,
pub size_bytes: u64,
pub modified: String,
pub referenced_in: Vec<String>,
}Fields
path: Stringabsolute_path: Stringasset_type: AssetTypesize_bytes: u64modified: Stringreferenced_in: Vec<String>Trait Implementations
Sourceimpl Clone for AssetDetailOutput
impl Clone for AssetDetailOutput
Sourcefn clone(&self) -> AssetDetailOutput
fn clone(&self) -> AssetDetailOutput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AssetDetailOutput
impl Debug for AssetDetailOutput
Sourceimpl<'de> Deserialize<'de> for AssetDetailOutput
impl<'de> Deserialize<'de> for AssetDetailOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AssetDetailOutput
impl JsonSchema for AssetDetailOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AssetDetailOutput
impl RefUnwindSafe for AssetDetailOutput
impl Send for AssetDetailOutput
impl Sync for AssetDetailOutput
impl Unpin for AssetDetailOutput
impl UnsafeUnpin for AssetDetailOutput
impl UnwindSafe for AssetDetailOutput