pub struct AssetSummary {
pub path: String,
pub asset_type: AssetType,
pub size_bytes: u64,
pub modified: String,
}Fields
path: Stringasset_type: AssetTypesize_bytes: u64modified: StringTrait Implementations
Sourceimpl Clone for AssetSummary
impl Clone for AssetSummary
Sourcefn clone(&self) -> AssetSummary
fn clone(&self) -> AssetSummary
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AssetSummary
impl Debug for AssetSummary
Sourceimpl<'de> Deserialize<'de> for AssetSummary
impl<'de> Deserialize<'de> for AssetSummary
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AssetSummary
impl JsonSchema for AssetSummary
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AssetSummary
impl RefUnwindSafe for AssetSummary
impl Send for AssetSummary
impl Sync for AssetSummary
impl Unpin for AssetSummary
impl UnsafeUnpin for AssetSummary
impl UnwindSafe for AssetSummary