pub struct ContentTypeDeleteOutput {
pub deleted: Vec<String>,
pub message: String,
}Fields
deleted: Vec<String>message: StringTrait Implementations
Sourceimpl Clone for ContentTypeDeleteOutput
impl Clone for ContentTypeDeleteOutput
Sourcefn clone(&self) -> ContentTypeDeleteOutput
fn clone(&self) -> ContentTypeDeleteOutput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ContentTypeDeleteOutput
impl Debug for ContentTypeDeleteOutput
Sourceimpl<'de> Deserialize<'de> for ContentTypeDeleteOutput
impl<'de> Deserialize<'de> for ContentTypeDeleteOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ContentTypeDeleteOutput
impl JsonSchema for ContentTypeDeleteOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ContentTypeDeleteOutput
impl RefUnwindSafe for ContentTypeDeleteOutput
impl Send for ContentTypeDeleteOutput
impl Sync for ContentTypeDeleteOutput
impl Unpin for ContentTypeDeleteOutput
impl UnwindSafe for ContentTypeDeleteOutput