pub struct ContentTypeEditOutput {
pub name: String,
pub message: String,
pub changes: Vec<String>,
}Fields
name: Stringmessage: Stringchanges: Vec<String>Trait Implementations
Sourceimpl Clone for ContentTypeEditOutput
impl Clone for ContentTypeEditOutput
Sourcefn clone(&self) -> ContentTypeEditOutput
fn clone(&self) -> ContentTypeEditOutput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ContentTypeEditOutput
impl Debug for ContentTypeEditOutput
Sourceimpl<'de> Deserialize<'de> for ContentTypeEditOutput
impl<'de> Deserialize<'de> for ContentTypeEditOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ContentTypeEditOutput
impl JsonSchema for ContentTypeEditOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ContentTypeEditOutput
impl RefUnwindSafe for ContentTypeEditOutput
impl Send for ContentTypeEditOutput
impl Sync for ContentTypeEditOutput
impl Unpin for ContentTypeEditOutput
impl UnsafeUnpin for ContentTypeEditOutput
impl UnwindSafe for ContentTypeEditOutput