pub struct IndexingInfo {
pub clear_before: bool,
pub recursive: bool,
pub override_existing: bool,
}Fields
clear_before: boolrecursive: booloverride_existing: boolTrait Implementations
Sourceimpl Clone for IndexingInfo
impl Clone for IndexingInfo
Sourcefn clone(&self) -> IndexingInfo
fn clone(&self) -> IndexingInfo
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for IndexingInfo
impl Debug for IndexingInfo
Sourceimpl<'de> Deserialize<'de> for IndexingInfo
impl<'de> Deserialize<'de> for IndexingInfo
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for IndexingInfo
impl JsonSchema for IndexingInfo
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for IndexingInfo
impl Serialize for IndexingInfo
impl Copy for IndexingInfo