pub struct SitemapInfo {
pub enabled: bool,
pub url_pattern: String,
pub priority: f32,
pub changefreq: String,
pub fetch_from: String,
pub parent_route: Option<ParentRouteInfo>,
}Fields
enabled: boolurl_pattern: Stringpriority: f32changefreq: Stringfetch_from: Stringparent_route: Option<ParentRouteInfo>Trait Implementations
Sourceimpl Clone for SitemapInfo
impl Clone for SitemapInfo
Sourcefn clone(&self) -> SitemapInfo
fn clone(&self) -> SitemapInfo
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SitemapInfo
impl Debug for SitemapInfo
Sourceimpl<'de> Deserialize<'de> for SitemapInfo
impl<'de> Deserialize<'de> for SitemapInfo
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SitemapInfo
impl JsonSchema for SitemapInfo
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SitemapInfo
impl RefUnwindSafe for SitemapInfo
impl Send for SitemapInfo
impl Sync for SitemapInfo
impl Unpin for SitemapInfo
impl UnwindSafe for SitemapInfo