pub struct SitemapRoute {
pub url: String,
pub priority: f32,
pub changefreq: String,
pub source: String,
}Fields
url: Stringpriority: f32changefreq: Stringsource: StringTrait Implementations
Sourceimpl Clone for SitemapRoute
impl Clone for SitemapRoute
Sourcefn clone(&self) -> SitemapRoute
fn clone(&self) -> SitemapRoute
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SitemapRoute
impl Debug for SitemapRoute
Sourceimpl<'de> Deserialize<'de> for SitemapRoute
impl<'de> Deserialize<'de> for SitemapRoute
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SitemapRoute
impl JsonSchema for SitemapRoute
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SitemapRoute
impl RefUnwindSafe for SitemapRoute
impl Send for SitemapRoute
impl Sync for SitemapRoute
impl Unpin for SitemapRoute
impl UnwindSafe for SitemapRoute