pub struct TemplateCreateOutput {
pub name: String,
pub file_path: String,
pub message: String,
}Fields
name: Stringfile_path: Stringmessage: StringTrait Implementations
Sourceimpl Clone for TemplateCreateOutput
impl Clone for TemplateCreateOutput
Sourcefn clone(&self) -> TemplateCreateOutput
fn clone(&self) -> TemplateCreateOutput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TemplateCreateOutput
impl Debug for TemplateCreateOutput
Sourceimpl<'de> Deserialize<'de> for TemplateCreateOutput
impl<'de> Deserialize<'de> for TemplateCreateOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for TemplateCreateOutput
impl JsonSchema for TemplateCreateOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for TemplateCreateOutput
impl RefUnwindSafe for TemplateCreateOutput
impl Send for TemplateCreateOutput
impl Sync for TemplateCreateOutput
impl Unpin for TemplateCreateOutput
impl UnwindSafe for TemplateCreateOutput