pub struct TemplateDetailOutput {
pub name: String,
pub content_types: Vec<String>,
pub file_path: String,
pub file_exists: bool,
pub variables: Vec<String>,
pub preview_lines: Vec<String>,
}Fields
name: Stringcontent_types: Vec<String>file_path: Stringfile_exists: boolvariables: Vec<String>preview_lines: Vec<String>Trait Implementations
Sourceimpl Clone for TemplateDetailOutput
impl Clone for TemplateDetailOutput
Sourcefn clone(&self) -> TemplateDetailOutput
fn clone(&self) -> TemplateDetailOutput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TemplateDetailOutput
impl Debug for TemplateDetailOutput
Sourceimpl<'de> Deserialize<'de> for TemplateDetailOutput
impl<'de> Deserialize<'de> for TemplateDetailOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for TemplateDetailOutput
impl JsonSchema for TemplateDetailOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for TemplateDetailOutput
impl RefUnwindSafe for TemplateDetailOutput
impl Send for TemplateDetailOutput
impl Sync for TemplateDetailOutput
impl Unpin for TemplateDetailOutput
impl UnwindSafe for TemplateDetailOutput