pub struct TemplateEditOutput {
pub name: String,
pub message: String,
pub changes: Vec<String>,
}Fields
name: Stringmessage: Stringchanges: Vec<String>Trait Implementations
Sourceimpl Clone for TemplateEditOutput
impl Clone for TemplateEditOutput
Sourcefn clone(&self) -> TemplateEditOutput
fn clone(&self) -> TemplateEditOutput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TemplateEditOutput
impl Debug for TemplateEditOutput
Sourceimpl<'de> Deserialize<'de> for TemplateEditOutput
impl<'de> Deserialize<'de> for TemplateEditOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for TemplateEditOutput
impl JsonSchema for TemplateEditOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for TemplateEditOutput
impl RefUnwindSafe for TemplateEditOutput
impl Send for TemplateEditOutput
impl Sync for TemplateEditOutput
impl Unpin for TemplateEditOutput
impl UnwindSafe for TemplateEditOutput