pub struct TemplateSummary {
pub name: String,
pub content_types: Vec<String>,
pub file_exists: bool,
pub file_path: String,
}Fields
name: Stringcontent_types: Vec<String>file_exists: boolfile_path: StringTrait Implementations
Sourceimpl Clone for TemplateSummary
impl Clone for TemplateSummary
Sourcefn clone(&self) -> TemplateSummary
fn clone(&self) -> TemplateSummary
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TemplateSummary
impl Debug for TemplateSummary
Sourceimpl<'de> Deserialize<'de> for TemplateSummary
impl<'de> Deserialize<'de> for TemplateSummary
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for TemplateSummary
impl JsonSchema for TemplateSummary
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for TemplateSummary
impl RefUnwindSafe for TemplateSummary
impl Send for TemplateSummary
impl Sync for TemplateSummary
impl Unpin for TemplateSummary
impl UnsafeUnpin for TemplateSummary
impl UnwindSafe for TemplateSummary