admin config runtime command: show and edit profile runtime settings.
RuntimeCommands reports and updates the environment, log level, output
format, and colour settings, persisting changes to the active profile.
Copyright (c) systemprompt.io — Business Source License 1.1. See https://systemprompt.io for licensing details.