Module interactive

Module interactive 

Interactive menu for cloud sync when no subcommand is given.

Prompts for push/pull direction and a source profile, then drives the SyncService to synchronise files for the profile’s configured tenant.

Copyright (c) systemprompt.io — Business Source License 1.1. See https://systemprompt.io for licensing details.

Enums

SyncType

Functions

select_sync_type