Interactive menu for cloud sync when no subcommand is given.
cloud sync
Prompts for push/pull direction and a source profile, then drives the SyncService to synchronise files for the profile’s configured tenant.
SyncService