Management of HTML templates and their content-type bindings.
Dispatches the web templates subcommands (TemplatesCommands) to list,
show, create, edit, and delete templates in the web templates config.
Management of HTML templates and their content-type bindings.
Dispatches the web templates subcommands (TemplatesCommands) to list,
show, create, edit, and delete templates in the web templates config.